----------------------------------------------------------------------
-- EQUIP: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE EQUIP (
   ID_EQUIP 		NUMBER,
   NOM 			VARCHAR2(25 CHAR)	NOT NULL,
   adreca 			VARCHAR2(40 CHAR),
   municipi 		VARCHAR2(25 CHAR),
   pais 			VARCHAR2(20 CHAR) 	NOT NULL,
   telefon 		CHAR(20),
   formaJuridica 	VARCHAR2(4 CHAR) 	NOT NULL,
   url			VARCHAR2(40 CHAR),
   CONSTRAINT PK_EQUIP PRIMARY KEY (ID_EQUIP) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
   CONSTRAINT UK_EQUIP UNIQUE (NOM) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
   CONSTRAINT CK_EQUIP CHECK (formaJuridica IN('CLUB', 'SAD')) 
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Equip INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insEquip BEFORE INSERT ON EQUIP
FOR EACH ROW
BEGIN
SELECT seq_Equip.NEXTVAL INTO :NEW.ID_EQUIP
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.NOM := UPPER(TRIM(:new.NOM));
  :NEW.adreca := UPPER(TRIM(:new.adreca));
  :NEW.municipi := UPPER(TRIM(:new.municipi));
  :NEW.pais := UPPER(TRIM(:new.pais));
  :NEW.formaJuridica := UPPER(TRIM(:new.formaJuridica));  
  :NEW.url := LOWER(TRIM(:new.url));
END insEquip ;
/
----------------------------------------------------------------------
-- POSICIO: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE POSICIO (
   ID_POSICIO 		NUMBER 				NOT NULL,
   nom			VARCHAR2(10 CHAR)		NOT NULL,
   CONSTRAINT PK_POSICIO PRIMARY KEY (ID_POSICIO) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
   CONSTRAINT UK_POSICIO UNIQUE (nom) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Posicio INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insPosicio BEFORE INSERT ON POSICIO
FOR EACH ROW
BEGIN
SELECT seq_Posicio.NEXTVAL INTO :NEW.ID_POSICIO
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.nom := UPPER(TRIM(:new.nom));
END insPosicio ;
/
----------------------------------------------------------------------
-- JUGADOR: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE JUGADOR
(
  ID_JUGADOR	NUMBER,
  nom			VARCHAR2(20 CHAR) 	NOT NULL,
  cognom1		VARCHAR2(20 CHAR) 	NOT NULL,
  cognom2		VARCHAR2(20 CHAR),
  genere		CHAR(1)           	NOT NULL,
  modalitat  	CHAR(15)           	NOT NULL,
  nacionalitat	VARCHAR2(20 CHAR) 	NOT NULL,
  dataNaixement	DATE				NOT NULL,
  alada 		NUMBER,
  pes			NUMBER,
  posicio		NUMBER,
  url			VARCHAR2(40 CHAR),
  urlVideo		VARCHAR2(40 CHAR),
  activitat	CHAR(7) DEFAULT 'ACTIU'    	NOT NULL,
  estat		CHAR(5) DEFAULT 'ALTA'     	NOT NULL,
  CONSTRAINT PK_JUGADOR PRIMARY KEY (ID_JUGADOR) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT FK_JUGADOR FOREIGN KEY (posicio) REFERENCES POSICIO(ID_POSICIO),
  CONSTRAINT CK1_JUGADOR CHECK (activitat IN('ACTIU', 'RETIRAT')),
  CONSTRAINT CK2_JUGADOR CHECK (estat IN('ALTA', 'BAIXA')),
  CONSTRAINT CK3_JUGADOR CHECK (genere IN('M', 'F')),
  CONSTRAINT CK4_JUGADOR CHECK (modalitat IN('NORMAL', 'CADIRA DE RODES'))
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Jugador INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insJugador BEFORE INSERT ON JUGADOR
FOR EACH ROW
BEGIN
SELECT seq_Jugador.NEXTVAL INTO :NEW.ID_JUGADOR
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.nom := UPPER(TRIM(:new.nom));
  :NEW.cognom1 := UPPER(TRIM(:new.cognom1));
  :NEW.cognom2 := UPPER(TRIM(:new.cognom2));
  :NEW.nacionalitat := UPPER(TRIM(:new.nacionalitat));
  :NEW.url := LOWER(TRIM(:new.url));
  :NEW.urlVideo := LOWER(TRIM(:new.urlVideo));
  :NEW.activitat := UPPER(:NEW.activitat);
  :NEW.estat := UPPER(:NEW.estat);  
END insJugador ;
/
----------------------------------------------------------------------
-- Taula Divisa
----------------------------------------------------------------------  ok
CREATE TABLE DIVISA 
(
   ID_DIVISA 	CHAR(3 CHAR), 
   nom 		VARCHAR2(20 CHAR), 
   CONSTRAINT PK_DIVISA PRIMARY KEY (ID_DIVISA) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
   CONSTRAINT UK_DIVISA UNIQUE (NOM) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insDivisa BEFORE INSERT ON Divisa 
FOR EACH ROW 
BEGIN
  :NEW.id_divisa := UPPER(TRIM(:NEW.id_divisa));
  :NEW.nom := UPPER(TRIM(:NEW.nom));
END insDivisa ;
/
----------------------------------------------------------------------
-- Taula Canvi
---------------------------------------------------------------------- ok
CREATE TABLE CANVI 
(
   divisa 	CHAR(3 CHAR)	NOT NULL,
   dia 	DATE			NOT NULL,
   canvi 	NUMBER 		NOT NULL,
   CONSTRAINT PK_CANVI PRIMARY KEY (DIVISA,DIA)	USING INDEX TABLESPACE 
TBS_BASKETBALL_INDEXS,
   CONSTRAINT FK_CANVI FOREIGN KEY (divisa) REFERENCES DIVISA(ID_DIVISA)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insCanvi BEFORE INSERT ON Canvi 
FOR EACH ROW 
BEGIN
  :NEW.divisa := UPPER(TRIM(:NEW.divisa));
END insCanvi ;
/
----------------------------------------------------------------------
-- CONTRACTE: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE CONTRACTE
(
  ID_CONTRACTE	NUMBER,
  JUGADOR   	NUMBER  NOT NULL,
  DATA_INICI	DATE	   NOT NULL,
  equipC		NUMBER  NOT NULL,
  equipV		NUMBER,
  durada		NUMBER  NOT NULL,
  unitat		CHAR(1) DEFAULT 'A',
  DATA_FI		DATE,
  salariBrut	NUMBER  NOT NULL,
  clausula		NUMBER  NOT NULL,
  valor		NUMBER,
  divisa		CHAR(3) DEFAULT 'EUR',
  CONSTRAINT PK_CONTRACTE PRIMARY KEY (ID_CONTRACTE) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT UK_CONTRACTE UNIQUE (JUGADOR, DATA_INICI) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,  
  CONSTRAINT FK1_CONTRACTE FOREIGN KEY (equipC) REFERENCES EQUIP(ID_EQUIP),
  CONSTRAINT FK2_CONTRACTE FOREIGN KEY (equipV) REFERENCES EQUIP(ID_EQUIP),
  CONSTRAINT FK3_CONTRACTE FOREIGN KEY (divisa) REFERENCES DIVISA(ID_DIVISA),
  CONSTRAINT CK1_CONTRACTE CHECK (unitat IN ('A','M','D'))
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Contracte INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE 
TRIGGER insContracte BEFORE INSERT ON CONTRACTE
FOR EACH ROW
BEGIN
SELECT seq_Contracte.NEXTVAL INTO :NEW.ID_CONTRACTE
FROM DUAL;
-- control data_inici del contracte:
IF (TO_CHAR(:NEW.data_inici,'MM') < 7 OR TO_CHAR(:NEW.data_inici,'MM') > 7 OR TO_CHAR(:NEW.data_inici,'DD') > 1) THEN
    raise_application_error( -20502, 'Sols podem entrar contractes el primer de juliol.');    
  END IF;
-- normalitzar format de les dades entrants
  :NEW.unitat := UPPER(TRIM(:NEW.unitat));
  :NEW.valor := (:NEW.SalariBrut + :NEW.Clausula) ;
  :NEW.divisa := UPPER(TRIM(:NEW.divisa)) ;

-- assigna 'A' (anys) per defecte al camp UNITAT i calcula la data_fi:   
  IF (:NEW.unitat IS NULL) THEN 
   :NEW.unitat := 'A';  
  END IF;  
  
    IF (:NEW.unitat = 'A') THEN
    :NEW.data_fi := (:NEW.data_inici + :NEW.durada * 365);
    ELSIF (:NEW.unitat = 'M') THEN
    :NEW.data_fi := (:NEW.data_inici + :NEW.durada * 30);
    ELSIF (:NEW.unitat = 'D') THEN
    :NEW.data_fi := (:NEW.data_inici + :NEW.durada);
    END IF;
-- assigna 'EUR' per defecte al camp DIVISA:    
  IF (:NEW.divisa IS NULL) THEN 
   :NEW.unitat := 'EUR';  
  END IF;  
  
END insContracte ;
/
----------------------------------------------------------------------
-- ENTRENADOR: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE ENTRENADOR
(
  ID_ENTRENADOR	NUMBER 			NOT NULL,
  nom			VARCHAR2(20 CHAR) 	NOT NULL,
  cognom1		VARCHAR2(20 CHAR) 	NOT NULL,
  cognom2		VARCHAR2(20 CHAR),
  telefon		VARCHAR2(20 CHAR),
  titol			VARCHAR2(20 CHAR),
  CONSTRAINT PK_ENTRENADOR PRIMARY KEY (ID_ENTRENADOR) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Entrenador INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insEntrenador BEFORE INSERT ON ENTRENADOR
FOR EACH ROW
BEGIN
SELECT seq_Entrenador.NEXTVAL INTO :NEW.ID_ENTRENADOR
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.nom := UPPER(TRIM(:new.nom));
  :NEW.cognom1 := UPPER(TRIM(:new.cognom1));
  :NEW.cognom2 := UPPER(TRIM(:new.cognom2));
  :NEW.titol := UPPER(TRIM(:new.titol));
END insEntrenador ;
/
----------------------------------------------------------------------
-- EQUIP_TECNIC: taula i disparador
----------------------------------------------------------------------  ok
CREATE TABLE EQUIP_TECNIC
(
  ENTRENADOR	NUMBER			NOT NULL,
  DATA_INICI	DATE			NOT NULL,
  equip			NUMBER 			NOT NULL,
  rol			VARCHAR2(20 CHAR),
  durada		NUMBER,
  CONSTRAINT PK_EQUIP_TECNIC PRIMARY KEY (ENTRENADOR, DATA_INICI) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT FK1_EQUIP_TECNIC FOREIGN KEY (ENTRENADOR) REFERENCES ENTRENADOR(ID_ENTRENADOR),
  CONSTRAINT FK2_EQUIP_TECNIC FOREIGN KEY (equip) REFERENCES EQUIP(ID_EQUIP)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insEquipTecnic BEFORE INSERT ON EQUIP_TECNIC
FOR EACH ROW
BEGIN
  -- normalitzar format de les dades entrants
  :NEW.rol := UPPER(TRIM(:new.rol));
END insEquipTecnic ;
/
----------------------------------------------------------------------
-- REPRESENTANT_LEGAL: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE REPRESENTANT_LEGAL
(
  ID_REPRESENTANT	NUMBER			NOT NULL,
  nom				VARCHAR2(20 CHAR)	NOT NULL,
  CONSTRAINT PK_REPRESENTANT_LEGAL PRIMARY KEY (ID_REPRESENTANT) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Representant_Legal INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insRepresentantLegal BEFORE INSERT ON REPRESENTANT_LEGAL
FOR EACH ROW
BEGIN
SELECT seq_Representant_Legal.NEXTVAL INTO :NEW.ID_REPRESENTANT
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.nom := UPPER(TRIM(:NEW.nom));
END insRepresentantLegal ;
/
----------------------------------------------------------------------
-- REP_EQUIP: taula i disparador
----------------------------------------------------------------------  ok
CREATE TABLE REP_EQUIP
(
  EQUIP		NUMBER				NOT NULL,
  DATA_INICI	DATE					NOT NULL,
  repLegal		NUMBER 				NOT NULL,
  protocol		VARCHAR2(20 CHAR),
  CONSTRAINT PK_REP_EQUIP PRIMARY KEY (EQUIP, DATA_INICI) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT FK1_REP_EQUIP FOREIGN KEY (equip) REFERENCES EQUIP(ID_EQUIP),
  CONSTRAINT FK2_REP_EQUIP FOREIGN KEY (repLegal) REFERENCES REPRESENTANT_LEGAL(ID_REPRESENTANT)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insRepEquip BEFORE INSERT ON REP_EQUIP
FOR EACH ROW
BEGIN
  -- normalitzar format de les dades entrants
  :NEW.protocol := UPPER(TRIM(:new.protocol));
END insRepEquip ;
/
----------------------------------------------------------------------
-- FEDERACIO: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE FEDERACIO
(
  ID_FEDERACIO	NUMBER				NOT NULL,
  NOM			VARCHAR2(40 CHAR)	NOT NULL,
  pais		VARCHAR2(20 CHAR),
  CONSTRAINT PK_FEDERACIO PRIMARY KEY (ID_FEDERACIO) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT UK_FEDERACIO UNIQUE (NOM) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Federacio INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insFederacio BEFORE INSERT ON FEDERACIO
FOR EACH ROW
BEGIN
SELECT seq_Federacio.NEXTVAL INTO :NEW.ID_FEDERACIO
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.NOM := UPPER(TRIM(:NEW.NOM));
  :NEW.pais := UPPER(TRIM(:NEW.pais));
END insFederacio ;
/
----------------------------------------------------------------------
-- PEDERA: taula
----------------------------------------------------------------------  ok
CREATE TABLE FEDERA
(
  FEDERACIO	NUMBER		NOT NULL,
  JUGADOR		NUMBER		NOT NULL,
  numero		VARCHAR2(10)	NOT NULL,
  alta			CHAR(1) DEFAULT 'S',
  CONSTRAINT PK_FEDERA PRIMARY KEY (FEDERACIO, JUGADOR) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT FK1_FEDERA FOREIGN KEY (FEDERACIO) REFERENCES FEDERACIO(ID_FEDERACIO),
  CONSTRAINT FK2_FEDERA FOREIGN KEY (JUGADOR) REFERENCES JUGADOR(ID_JUGADOR),
  CONSTRAINT UK_FEDERA UNIQUE (FEDERACIO, NUMERO) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT CK_FEDERA CHECK (alta IN('S', 'N'))
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insFedera BEFORE INSERT ON FEDERA
FOR EACH ROW
BEGIN
  -- normalitzar format de les dades entrants
  :NEW.alta := UPPER(TRIM(:NEW.alta));
END insFedera ;
/
----------------------------------------------------------------------
-- REPRESENTANT: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE REPRESENTANT
(
  ID_REPRESENTANT	NUMBER				NOT NULL,
  nom				VARCHAR2(30 CHAR)	NOT NULL,
  telefon			VARCHAR2(20 CHAR),
  CONSTRAINT PK_REPRESENTANT PRIMARY KEY (ID_REPRESENTANT) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Representant INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insRepresentant 
BEFORE INSERT ON REPRESENTANT
FOR EACH ROW
BEGIN
SELECT seq_Representant.NEXTVAL INTO :NEW.ID_REPRESENTANT
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.nom := UPPER(TRIM(:NEW.nom));  
END insRepresentant ;
/
----------------------------------------------------------------------
-- REP_JUGADOR: taula
----------------------------------------------------------------------  ok
CREATE TABLE REP_JUGADOR
(
  JUGADOR		NUMBER		NOT NULL,
  DATA_INICI	DATE		NOT NULL,
  representant	NUMBER		NOT NULL,
  data_fi		DATE,
  CONSTRAINT PK_REP_JUGADOR PRIMARY KEY (JUGADOR, DATA_INICI) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT FK1_REP_JUGADOR FOREIGN KEY (JUGADOR) REFERENCES JUGADOR(ID_JUGADOR),
  CONSTRAINT FK2_REP_JUGADOR FOREIGN KEY (representant) REFERENCES REPRESENTANT(ID_REPRESENTANT),
  CONSTRAINT CK_REP_JUGADOR CHECK (data_fi >= data_inici)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
/
----------------------------------------------------------------------
-- BAIXA: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE BAIXA
(
  ID_BAIXA		NUMBER		NOT NULL,
  CONSTRAINT PK_BAIXA PRIMARY KEY (ID_BAIXA) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Baixa INCREMENT BY 1 START WITH 1;
/
----------------------------------------------------------------------
-- BAIXA_METGE: taula i disparador
----------------------------------------------------------------------  ok
CREATE TABLE BAIXA_METGE
(
  ID_BAIXA		NUMBER				NOT NULL,
  diagnosi		VARCHAR2(100 CHAR)		NOT NULL,
  CONSTRAINT PK_BAIXA_METGE PRIMARY KEY (ID_BAIXA) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insBaixaMetge 
BEFORE INSERT ON BAIXA_METGE
FOR EACH ROW
BEGIN
SELECT seq_Baixa.NEXTVAL INTO :NEW.ID_BAIXA
FROM DUAL;
  -- normalitzar format de les dades entrants
 :NEW.diagnosi := UPPER(TRIM(:new.diagnosi));
  -- crea registre a la taula BAIXA amb el mateix identificador:
  INSERT INTO BAIXA VALUES(:NEW.ID_BAIXA);
END insBaixaMetge ;
/
----------------------------------------------------------------------
-- BAIXA_MP: taula i disparador
----------------------------------------------------------------------  ok
CREATE TABLE BAIXA_MP
(
  ID_BAIXA		NUMBER				NOT NULL,
  obs			VARCHAR2(100 CHAR),
  CONSTRAINT PK_BAIXA_MP PRIMARY KEY (ID_BAIXA) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insBaixaMP
BEFORE INSERT ON BAIXA_MP
FOR EACH ROW
BEGIN
SELECT seq_Baixa.NEXTVAL INTO :NEW.ID_BAIXA
FROM DUAL;
  -- normalitzar format de les dades entrants
 :NEW.obs := UPPER(TRIM(:new.obs));
  -- crea registre a la taula BAIXA amb el mateix identificador:
  INSERT INTO BAIXA VALUES(:NEW.ID_BAIXA);
END insBaixaMP ;
/
----------------------------------------------------------------------
-- CAUSA_BAIXA: taula
----------------------------------------------------------------------  ok
CREATE TABLE CAUSA_BAIXA
(
  JUGADOR		NUMBER	NOT NULL,
  ID_BAIXA		NUMBER	NOT NULL,
  dia_Baixa		DATE		NOT NULL,
  dia_Alta		DATE,
  CONSTRAINT PK_CAUSA_BAIXA PRIMARY KEY (JUGADOR, ID_BAIXA) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT FK1_CAUSA_BAIXA FOREIGN KEY (JUGADOR) REFERENCES JUGADOR(ID_JUGADOR),
  CONSTRAINT FK2_CAUSA_BAIXA FOREIGN KEY (ID_BAIXA) REFERENCES BAIXA(ID_BAIXA)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
/
----------------------------------------------------------------------
-- TEMPORADA: taula
----------------------------------------------------------------------  ok
CREATE TABLE TEMPORADA 
(
   ID_TEMPORADA 	VARCHAR2(9 CHAR)	NOT NULL,
   CONSTRAINT PK_TEMPORADA PRIMARY KEY (ID_TEMPORADA) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Temporada INCREMENT BY 1 START WITH 2009;
CREATE OR REPLACE
TRIGGER insTemporada
BEFORE INSERT ON TEMPORADA
FOR EACH ROW
BEGIN
SELECT seq_Temporada.NEXTVAL INTO :NEW.ID_Temporada
FROM DUAL;
  :NEW.id_temporada := to_char(:NEW.id_temporada) || '-' || to_char(:NEW.id_temporada + 1);
END insTemporada ;
/
----------------------------------------------------------------------
-- COMPETICIO: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE COMPETICIO
(
  ID_COMPETICIO		NUMBER			NOT NULL,
  nom				VARCHAR2(30 CHAR)	NOT NULL,
  ambit			CHAR(11)	NOT NULL,
  genere			CHAR(1)	NOT NULL,
  modalitat		CHAR(15)	NOT NULL,
  categoria		CHAR(7)	NOT NULL,
  factor			NUMBER	DEFAULT 0	NOT NULL,  
  CONSTRAINT PK_COMPETICIO PRIMARY KEY (ID_COMPETICIO) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT CK1_COMPETICIO CHECK (ambit IN('NACIONAL', 'CONTINENTAL')),
  CONSTRAINT CK2_COMPETICIO CHECK (genere IN('M', 'F')),
  CONSTRAINT CK3_COMPETICIO CHECK (modalitat IN('NORMAL', 'CADIRA DE RODES')),
  CONSTRAINT CK4_COMPETICIO CHECK (categoria IN('PRIMERA', 'SEGONA'))
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Competicio INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insCompeticio BEFORE INSERT ON COMPETICIO
FOR EACH ROW
BEGIN
SELECT seq_Competicio.NEXTVAL INTO :NEW.ID_COMPETICIO
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.nom := UPPER(TRIM(:NEW.nom));
  :NEW.ambit := UPPER(TRIM(:NEW.ambit));
  :NEW.genere := UPPER(TRIM(:NEW.genere));
  :NEW.modalitat := UPPER(TRIM(:NEW.modalitat));
  :NEW.categoria := UPPER(TRIM(:NEW.categoria));	
END insCompeticio ;
/
----------------------------------------------------------------------
-- NACIONAL: taula i disparador
----------------------------------------------------------------------  ok
CREATE TABLE NACIONAL (
   ID_COMPETICIO	NUMBER 		NOT NULL,
   pais			VARCHAR2(25 CHAR)	NOT NULL,
   temporada		VARCHAR2(9 CHAR)	NOT NULL,
   numArbitres		NUMBER 	NOT NULL,
   CONSTRAINT PK_NACIONAL PRIMARY KEY (ID_COMPETICIO) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
   CONSTRAINT FK1_NACIONAL FOREIGN KEY (ID_COMPETICIO) REFERENCES COMPETICIO(ID_COMPETICIO),
   CONSTRAINT FK2_NACIONAL FOREIGN KEY (TEMPORADA) REFERENCES TEMPORADA(ID_TEMPORADA),
   CONSTRAINT CK_NACIONAL CHECK (numArbitres <= 3)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insNacional BEFORE INSERT ON NACIONAL
FOR EACH ROW
BEGIN
  -- normalitzar format de les dades entrants
  :NEW.pais := UPPER(TRIM(:NEW.pais));
  -- inicialitza el nmero d'rbitres:
  IF (:NEW.numArbitres IS NULL) THEN
	:NEW.numArbitres := 3;
  END IF;
END insNacional ;
/
----------------------------------------------------------------------
-- INTERNACIONAL: taula i disparador
----------------------------------------------------------------------  ok
CREATE TABLE INTERNACIONAL (
   ID_COMPETICIO 	NUMBER		NOT NULL,
   continent		VARCHAR2(20 CHAR)	NOT NULL,
   anyComp			NUMBER(4)		NOT NULL,
   numArbitres		NUMBER,
   CONSTRAINT PK_INTERNACIONAL PRIMARY KEY (ID_COMPETICIO) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
   CONSTRAINT FK_INTERNACIONAL FOREIGN KEY (ID_COMPETICIO) REFERENCES COMPETICIO(ID_COMPETICIO),
   CONSTRAINT CK1_INTERNACIONAL CHECK (numArbitres <= 4),   
   CONSTRAINT CK2_INTERNACIONAL CHECK (anyComp BETWEEN 1950 AND 2015)   
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insInternacional BEFORE INSERT ON INTERNACIONAL
FOR EACH ROW
BEGIN
  -- normalitzar format de les dades entrants
  :NEW.continent := UPPER(TRIM(:NEW.continent));
  -- inicialitza el nmero d'rbitres:
  IF (:NEW.numArbitres IS NULL) THEN
	:NEW.numArbitres := 4;
  END IF;
END insInternacional ;
/
----------------------------------------------------------------------
-- PARTIT: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE PARTIT
(
  ID_PARTIT	NUMBER 	NOT NULL,
  dia_hora		TIMESTAMP(0),
  municipi		VARCHAR2(25 CHAR),
  pavello		VARCHAR2(25 CHAR),
  eqLocal		NUMBER	NOT NULL,
  eqVisitant	NUMBER	NOT NULL,
  competicio	NUMBER 	NOT NULL,
  estat	CHAR(1) DEFAULT 'P'	NOT NULL,
  CONSTRAINT PK_PARTIT PRIMARY KEY (ID_PARTIT) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT FK1_PARTIT FOREIGN KEY (eqLocal) REFERENCES EQUIP(ID_EQUIP),
  CONSTRAINT FK2_PARTIT FOREIGN KEY (eqVisitant) REFERENCES EQUIP(ID_EQUIP),
  CONSTRAINT FK3_PARTIT FOREIGN KEY (competicio) REFERENCES COMPETICIO(ID_COMPETICIO),
  CONSTRAINT CK_PARTIT CHECK (estat IN('P','I','F'))
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Partit INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insPartit 
BEFORE INSERT ON PARTIT
FOR EACH ROW
BEGIN
SELECT seq_Partit.NEXTVAL INTO :NEW.ID_PARTIT
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.municipi := UPPER(TRIM(:NEW.municipi));
  :NEW.pavello := UPPER(TRIM(:NEW.pavello));
END insPartit ;
/
----------------------------------------------------------------------
-- ARBITRE: taula, seqncia i disparador
----------------------------------------------------------------------  ok
CREATE TABLE ARBITRE
(
  ID_ARBITRE	NUMBER 				NOT NULL,
  nom			VARCHAR2(20 CHAR) 	NOT NULL,
  cognom1		VARCHAR2(20 CHAR) 	NOT NULL,
  cognom2		VARCHAR2(20 CHAR),
  telefon		VARCHAR2(20 CHAR),
  CONSTRAINT PK_ARBITRE PRIMARY KEY (ID_ARBITRE) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE SEQUENCE seq_Arbitre INCREMENT BY 1 START WITH 1;
CREATE OR REPLACE
TRIGGER insArbitre 
BEFORE INSERT ON ARBITRE
FOR EACH ROW
BEGIN
SELECT seq_Arbitre.NEXTVAL INTO :NEW.ID_ARBITRE
FROM DUAL;
  -- normalitzar format de les dades entrants
  :NEW.nom := UPPER(TRIM(:NEW.nom));
  :NEW.cognom1 := UPPER(TRIM(:NEW.cognom1));
  :NEW.cognom2 := UPPER(TRIM(:NEW.cognom2));
END insArbitre ;
/
----------------------------------------------------------------------
-- EQUIP_ARBITRAL: taula i disparador
----------------------------------------------------------------------  ok
CREATE TABLE EQUIP_ARBITRAL
(
  PARTIT		NUMBER				NOT NULL,
  ARBITRE		NUMBER				NOT NULL,
  competicio	NUMBER				NOT NULL,
  rol			VARCHAR2(20 CHAR)	NOT NULL,
  CONSTRAINT PK_EQUIP_ARBITRAL PRIMARY KEY (PARTIT, ARBITRE) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
  CONSTRAINT FK1_EQUIP_ARBITRAL FOREIGN KEY (PARTIT) REFERENCES PARTIT(ID_PARTIT),
  CONSTRAINT FK2_EQUIP_ARBITRAL FOREIGN KEY (ARBITRE) REFERENCES ARBITRE(ID_ARBITRE),
  CONSTRAINT FK3_EQUIP_ARBITRAL FOREIGN KEY (competicio) REFERENCES COMPETICIO(ID_COMPETICIO)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
CREATE OR REPLACE
TRIGGER insEquipArbitral BEFORE INSERT ON EQUIP_ARBITRAL
FOR EACH ROW
BEGIN
  -- normalitzar format de les dades entrants
  :NEW.rol := UPPER(TRIM(:NEW.rol));
END insEquipArbitral ;
/
----------------------------------------------------------------------
-- CLUB: taula
----------------------------------------------------------------------  ok
CREATE TABLE CLUB 
(
   ID_EQUIP 		NUMBER 				NOT NULL,
   socis			NUMBER				NOT NULL,
   dia			DATE					NOT NULL,
   CONSTRAINT PK_CLUB PRIMARY KEY (ID_EQUIP) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
   CONSTRAINT FK_CLUB FOREIGN KEY (ID_EQUIP) REFERENCES EQUIP(ID_EQUIP)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
----------------------------------------------------------------------
-- CLASSIFICACIO: taula
----------------------------------------------------------------------  ok
CREATE TABLE CLASSIFICACIO 
(
   COMPETICIO	NUMBER		NOT NULL,
   EQUIP 		NUMBER		NOT NULL,
   punts		NUMBER DEFAULT 0			NOT NULL,
   CONSTRAINT PK_CLASSIFICACIO PRIMARY KEY (COMPETICIO, EQUIP) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
   CONSTRAINT FK1_CLASSIFICACIO FOREIGN KEY (COMPETICIO) REFERENCES COMPETICIO(ID_COMPETICIO),   
   CONSTRAINT FK2_CLASSIFICACIO FOREIGN KEY (EQUIP) REFERENCES EQUIP(ID_EQUIP)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
----------------------------------------------------------------------
-- PARTICIPA: taula
----------------------------------------------------------------------  ok 
CREATE TABLE PARTICIPA 
(
   PARTIT	NUMBER		NOT NULL,
   JUGADOR	NUMBER		NOT NULL,
   minuts	NUMBER,
   PT		NUMBER,
   T1E	NUMBER,
   T1I	NUMBER,
   T2E	NUMBER,
   T2I	NUMBER,
   T3E	NUMBER,
   T3I	NUMBER,
   RD		NUMBER,
   RO		NUMBER,
   ASS	NUMBER,
   TF		NUMBER,
   TC		NUMBER,
   PR		NUMBER,
   PP		NUMBER,
   FR		NUMBER,
   FC		NUMBER,
   V		NUMBER,
   VP		NUMBER,
   CONSTRAINT PK_PARTICIPA PRIMARY KEY (PARTIT, JUGADOR) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS,
   CONSTRAINT FK1_PARTICIPA FOREIGN KEY (PARTIT) REFERENCES PARTIT(ID_PARTIT),
   CONSTRAINT FK2_PARTICIPA FOREIGN KEY (JUGADOR) REFERENCES JUGADOR(ID_JUGADOR)
)
TABLESPACE TBS_BASKETBALL_TAULES ;
/*********************************************************************
ALTRES TAULES: LOG i MODEL ESTADISTIC
*********************************************************************/
----------------------------------------------------------------------
-- TAULA LOG                                                
----------------------------------------------------------------------  
CREATE TABLE LOG
(
  text VARCHAR2(2048 CHAR)
  --entrada         NUMBER		NOT NULL,
  --data_hora       VARCHAR2(20 CHAR)	NOT NULL,
  --nomProcediment VARCHAR2(20 CHAR)	NOT NULL,
  --paramEntrada	  VARCHAR2(256 CHAR)	NOT NULL,
  --paramSortida	  VARCHAR2(8 CHAR)	NOT NULL,
  --CONSTRAINT PK_LOG PRIMARY KEY (entrada) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
----------------------------------------------------------------------
-- MODUL ESTADISTIC - PUNT 8.1
-- El nmero total de jugadors en actiu en tots els gneres i modalitats.
-- Cada cop que s'insereix o esborra un jugador en ACTIU o canvia l'estat del jugador a 'RETIRAT' s'actualitza el valor 'jugadors ' a EST_81
----------------------------------------------------------------------  ok
CREATE TABLE EST_81 
(
   genere		VARCHAR2(1 CHAR)		NOT NULL,
   modalitat 	VARCHAR2(15 CHAR)	NOT NULL,
   jugadors	NUMBER DEFAULT 0		NOT NULL,
   CONSTRAINT PK_EST_81 PRIMARY KEY (genere, modalitat) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
/
----------------------------------------------------------------------
-- MODUL ESTADISTIC - PUNT 8.2
-- Donada una competici, el seu mxim anotador en la temporada en curs (o b la darrera temporada, si ens trobem en el perode entre temporades).
-- Cada cop que es modifica el valor de 'PUNTS' a la taula 'PARTICIPA' s'actualitza la taula temporal d'anotadors.
----------------------------------------------------------------------  ok
CREATE TABLE EST_82 
(
   competicio		VARCHAR2(30 CHAR)	NOT NULL,
   jugador			VARCHAR2(40 CHAR)	NOT NULL,
   punts			NUMBER DEFAULT 0	NOT NULL,
   CONSTRAINT PK_EST_82 PRIMARY KEY (competicio) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
----------------------------------------------------------------------
-- MODUL ESTADISTIC - PUNT 8.3
-- El jugador ms ben pagat de cada modalitat i gnere. 
----------------------------------------------------------------------  ok
CREATE TABLE EST_83 
(
   modalitat	VARCHAR2(15 CHAR)	NOT NULL,
   genere		VARCHAR2(1 CHAR)	NOT NULL,
   jugador		VARCHAR2(40 CHAR)	NOT NULL,
   sou		NUMBER DEFAULT 0	NOT NULL,
   CONSTRAINT PK_EST_83 PRIMARY KEY (modalitat, genere) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
/
----------------------------------------------------------------------
-- MODUL ESTADISTIC - PUNT 8.4
-- El jugador amb ms guanys acumulats al llarg de tota la seva carrera esportiva. 
----------------------------------------------------------------------  ok
CREATE TABLE EST_84 
(
   jugador			VARCHAR2(40 CHAR)	NOT NULL,
   guanysAcumulats	NUMBER DEFAULT 0	NOT NULL,
   CONSTRAINT PK_EST_84 PRIMARY KEY (jugador) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
----------------------------------------------------------------------
-- MODUL ESTADISTIC - PUNT 8.5
-- Donat un pas, una temporada, un gnere i una modalitat, el sou mig anual dels jugadors. 
----------------------------------------------------------------------  ok
CREATE TABLE EST_85 
(
   pais		VARCHAR2(20 CHAR)	NOT NULL,
   temporada	VARCHAR2(9 CHAR)	NOT NULL,   
   genere		VARCHAR2(1 CHAR)	NOT NULL,
   modalitat	VARCHAR2(15 CHAR)	NOT NULL,
   souMig		NUMBER DEFAULT 0	NOT NULL,
   CONSTRAINT PK_EST_85 PRIMARY KEY (pais, temporada, genere, modalitat) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
----------------------------------------------------------------------
-- MODUL ESTADISTIC - PUNT 8.6
-- Donada una competici i una temporada, els millors equips ofensius i defensius. 
----------------------------------------------------------------------  ok
CREATE TABLE EST_86 
(
   competicio		VARCHAR2(30 CHAR)	NOT NULL,
   temporada  		VARCHAR2(9 CHAR)	NOT NULL,
   equipOf			VARCHAR2(25 CHAR)	NOT NULL,
   valorOf			NUMBER (6,2) DEFAULT 0		NOT NULL,
   equipDef		VARCHAR2(25 CHAR)	NOT NULL,
   valorDef		NUMBER (6,2) DEFAULT 0	NOT NULL,
   CONSTRAINT PK_EST_86 PRIMARY KEY (competicio, temporada) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
/
----------------------------------------------------------------------
-- MODUL ESTADISTIC - PUNT 8.7
-- Per a cada gnere i modalitat, el millor jugador del mn en el darrer any (mitjana de valoracions 
-- ponderades ms alta). 
----------------------------------------------------------------------  ok
CREATE TABLE EST_87 (
   genere			VARCHAR2(1 CHAR)	NOT NULL,
   modalitat 		VARCHAR2(15 CHAR)	NOT NULL,
   millorJugador	VARCHAR2(40 CHAR)	NOT NULL,
   valorMig		NUMBER(8,2) DEFAULT 0		NOT NULL,
   CONSTRAINT PK_ESTADISTIC_87 PRIMARY KEY (genere, modalitat) USING INDEX TABLESPACE TBS_BASKETBALL_INDEXS
)
TABLESPACE TBS_BASKETBALL_TAULES ;
/
----------------------------------------------------------------------
-- TAULA LOG_CONSULTES_SLT7                                
----------------------------------------------------------------------  
CREATE TABLE LOG_CONSULTES_SLT7
(
  data_hora TIMESTAMP(0),
  consulta  VARCHAR2(10 CHAR),
  resultat  VARCHAR2(2 CHAR),
  paramEmtrada  VARCHAR2(512)
)
TABLESPACE TBS_BASKETBALL_TAULES ;