/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:			ins_Jugador
@Funcionalitat:	Afegir un nou jugador
@params IN:		paramNom VARCHAR2(20 CHAR), 
				paramCognom1 VARCHAR2(20 CHAR),
				paramCognom2 VARCHAR2(20 CHAR),
				paramGenere VARCHAR2(7 CHAR), -- 'M' o 'F'
				paramModalitat VARCHAR2(15 CHAR), 'NORMAL' o 'CADIRA DE RODES'
				paramNacionalitat VARCHAR2(20 CHAR),	
				paramDataNaixement DATE,
				paramAlada NUMBER,
				paramPes NUMBER,
				paramPosicio NUMBER,
				paramUrl VARCHAR2(20 CHAR),
				paramUrlVideo VARCHAR2(20 CHAR),
				paramActivitat CHAR(7), -- 'ACTIU' o 'RETIRAT'
				paramEstat CHAR(5), -- 'ALTA' o 'BAIXA'
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE ins_Jugador 
(
  paramNom 		IN JUGADOR.nom%TYPE, 
  paramCognom1		IN JUGADOR.cognom1%TYPE, 
  paramCognom2		IN JUGADOR.cognom2%TYPE, 
  paramGenere		IN JUGADOR.genere%TYPE,
  paramModalitat	IN JUGADOR.modalitat%TYPE,
  paramNacionalitat	IN JUGADOR.nacionalitat%TYPE, 
  paramDataNaixement	IN JUGADOR.dataNaixement%TYPE, 
  paramAlada		IN JUGADOR.alada%TYPE, 
  paramPes			IN JUGADOR.pes%TYPE, 
  paramPosicio		IN JUGADOR.posicio%TYPE, 
  paramUrl 		IN JUGADOR.url%TYPE, 
  paramUrlVideo		IN JUGADOR.urlVideo%TYPE,  
  paramActivitat 	IN JUGADOR.activitat%TYPE, 
  paramEstat 		IN JUGADOR.estat%TYPE,

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
  
  existeix	NUMBER;

BEGIN
RSP := 'KO';
procediment := 'ins_Jugador'; 
paramEntrada := 'Nom: ' || paramNom || 
          ' - Cognom1: ' || paramCognom1||
          ' - Cognom2: ' || paramCognom2 || 
          ' - Genere: ' || paramGenere || 
          ' - Modalitat: ' || paramModalitat || 
          ' - Nacionalitat: ' || paramNacionalitat ||   
          ' - Data naixement: ' || paramDataNaixement ||
          ' - Alada: ' || paramAlada ||
          ' - Pes: ' || paramPes ||
          ' - Posicio: ' || paramPosicio ||
          ' - URL: ' || paramUrl ||
          ' - URL Video: ' || paramUrlVideo ||
          ' - Activitat: ' || paramActivitat ||
          ' - Estat: ' || paramEstat;	

-- comprovar dades d'entrada:   
	IF (paramNom IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NOM.';
		RAISE ERR_NN;
	END IF;
	IF (paramCognom1 IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp Cognom1.';
		RAISE ERR_NN;
	END IF;
	IF (paramGenere IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp GENERE.';
		RAISE ERR_NN;
    ELSIF (paramGenere NOT IN('M','F')) THEN
      MSG_EX := 'GENERE pot prendre valors: M o F';
      RAISE ERR_EX;    
	END IF;
	IF (paramModalitat IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp MODALITAT.';
		RAISE ERR_NN;
    ELSIF (paramModalitat NOT IN('NORMAL','CADIRA DE RODES')) THEN
      MSG_EX := 'MODALITAT pot prendre valors: NORMAL o CADIRA DE RODES';
      RAISE ERR_EX;
	END IF;
	IF (paramNacionalitat IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NACIONALITAT.';
		RAISE ERR_NN;
	END IF;
	IF (paramDataNaixement IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp DATA NAIXEMENT.';
		RAISE ERR_NN;
	END IF;
	IF (paramActivitat IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp ACTIVITAT.';
		RAISE ERR_NN;
    ELSIF (paramActivitat NOT IN('ACTIU','RETIRAT')) THEN
      MSG_EX := 'ACTIVITAT pot prendre valors: ACTIU o RETIRAT';
      RAISE ERR_EX;    
	END IF;
  IF (paramEstat IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp ESTAT.';
		RAISE ERR_NN;
    ELSIF (paramEstat NOT IN('ALTA','BAIXA')) THEN
      MSG_EX := 'ESTAT pot prendre valors: ALTA o BAIXA';
      RAISE ERR_EX;    
	END IF;
  
-- comprovar claus foranes:
  IF (paramPosicio IS NOT NULL) THEN
    SELECT COUNT(*) INTO existeix
    FROM POSICIO
    WHERE id_posicio = paramPosicio;
	
    IF (existeix = 0) THEN
      MSG_EX := 'BASE(1) - ESCORTA(2) - ALER(3) - ALER-PIVOT(4) - PIVOT(5)';
      RAISE ERR_EX;
    END IF;
  END IF;

-- INSERT del nou jugador
INSERT INTO JUGADOR VALUES ('', paramNom, paramCognom1, paramCognom2, paramGenere, paramModalitat, paramNacionalitat, paramDataNaixement, paramAlada, paramPes, paramPosicio, paramUrl, paramUrlVideo, paramActivitat, paramEstat);
COMMIT;
-- actualitza dades estadstiques
  IF (paramActivitat = 'ACTIU') THEN
	act_EST_81 (paramGenere, paramModalitat, '+', RSP);
  END IF;

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta JUGADOR realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Jugador ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Jugador
@Funcionalitat:		Eliminar un jugador de la BD.
@restriccions		No es pot eliminar un jugador que t, o ha tingut, contracte amb algun equip. Tampoc aquell que consta com a 'RETIRAT'.
@params IN			paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
@return			RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE del_Jugador 
(
  paramID	IN JUGADOR.id_jugador%TYPE,
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
  oldGenere VARCHAR2(2);
  oldModalitat VARCHAR2(15);
  oldActivitat VARCHAR2(7);
    
BEGIN
  RSP := 'KO';
  procediment := 'del_Jugador'; 
  paramEntrada := 'ID_JUGADOR' || paramID;

-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador del jugador';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM Jugador
  WHERE id_jugador = paramID;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- comprova si t contractes
  SELECT count(*) INTO existeix
  FROM Contracte
  WHERE jugador = paramID;
	
  IF (existeix > 0) THEN
	MSG_EX := 'El jugador ' || paramID || ' t contractes.';
	RAISE ERR_EX;
  END IF;

-- dades estadstiques: genere i modalitat
  SELECT genere, modalitat, activitat INTO oldGenere, oldModalitat, oldActivitat
  FROM JUGADOR
  WHERE Jugador.id_jugador = paramID;

-- elimina jugador en 'ACTIU':	
  IF (oldActivitat != 'ACTIU') THEN    
	DELETE FROM JUGADOR WHERE id_jugador = paramID;
	ELSE
		MSG_EX := 'El jugador ' || paramID || ' est RETIRAT.';
		RAISE ERR_EX;
  END IF;
COMMIT;
-- actualitza dades estadstiques
act_EST_81 (oldGenere, oldModalitat, '-', RSP);

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - JUGADOR eliminat de la BD.' );

  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Jugador ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Jugador
@Funcionalitat:		Modificar un dels atributs del jugador
@param:				paramID NUMBER,
					paramNacionalitat VARCHAR2(20),
					paramAlada NUMBER,
					paramPes NUMBER,
					paramPosicio VARCHAR2(10),
					paramUrl VARCHAR2(20),
					paramUrlVideo VARCHAR2(20),
					paramActivitat VARCHAR2(7),
					paramEstat VARCHAR2(20),
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
@return			RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE upd_Jugador 
(
  paramID			IN JUGADOR.id_jugador%TYPE,
  paramNacionalitat	IN JUGADOR.nacionalitat%TYPE,
  paramAlada		IN JUGADOR.alada%TYPE,
  paramPes			IN JUGADOR.pes%TYPE,
  paramPosicio		IN JUGADOR.posicio%TYPE,
  paramUrl			IN JUGADOR.url%TYPE,
  paramUrlVideo		IN JUGADOR.urlVideo%TYPE,
  paramActivitat	IN JUGADOR.activitat%TYPE,
  paramEstat		IN JUGADOR.estat%TYPE,
  
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix 	INTEGER;
  oldGenere	VARCHAR2(7);
  oldModalitat	VARCHAR2(15);
  oldActivitat	VARCHAR2(7);
    
BEGIN
  RSP := 'KO';
  procediment := 'upd_Jugador'; 
  paramEntrada := 'ID_JUGADOR' || paramID ||
				' - Nacionalitat: ' || paramNacionalitat ||
				' - Alada; ' || paramAlada ||
				' - Pes; ' || paramPes ||
				' - Posicio; ' || paramPosicio ||
				' - URL; ' || paramUrl ||
				' - URL video ' || paramUrlVideo ||
				' - Activitat; ' || paramActivitat ||
				' - Estat: ' || paramEstat ;

  IF ((paramNacionalitat IS NULL)
    AND (paramAlada IS NULL)
      AND (paramPes IS NULL)
        AND (paramPosicio IS NULL)
          AND (paramUrl IS NULL)
            AND (paramUrlVideo IS NULL)
              AND (paramActivitat IS NULL)
                AND (paramEstat IS NULL)) THEN
    MSG_NN := 'No has entrat cap dada a modificar!';
    RAISE ERR_NN;
  END IF;
  
-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador del jugador';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:
  SELECT count(*) INTO existeix 
  FROM JUGADOR
  WHERE id_jugador = paramID;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- Corregir o modificar algun dels atributs inicials.    
  IF (paramNacionalitat IS NOT NULL) THEN
	UPDATE JUGADOR SET nacionalitat = paramNacionalitat
	WHERE id_jugador = paramID;
  END IF;
	
  IF (paramAlada IS NOT NULL) THEN
	UPDATE JUGADOR SET alada = paramAlada
	WHERE id_jugador = paramID;
  END IF;
  
  IF (paramPes IS NOT NULL) THEN
	UPDATE JUGADOR SET pes = paramPes   
	WHERE id_jugador = paramID;
  END IF;

  IF (paramPosicio IS NOT NULL) THEN
	-- comprovar si existeix la POSICIO:
		SELECT COUNT(*) INTO existeix
    FROM POSICIO
    WHERE id_posicio = paramPosicio;
	
		IF (existeix = 0) THEN
      MSG_EX := 'BASE(1) - ESCORTA(2) - ALER(3) - ALER-PIVOT(4) - PIVOT(5)';
      RAISE ERR_EX;
    END IF;
	UPDATE JUGADOR SET posicio = paramPosicio   
	WHERE id_jugador = paramID;
  END IF;
  
  IF (paramUrl IS NOT NULL) THEN
	UPDATE JUGADOR SET url = paramUrl   
	WHERE id_jugador = paramID;
  END IF;
  
  IF (paramUrlVideo IS NOT NULL) THEN
	UPDATE JUGADOR SET urlVideo = paramUrlVideo   
	WHERE id_jugador = paramID;
  END IF;
  
-- modificaci del atribut ACTIVITAT com a conseqncia d'un canvi en l'activitat del jugador:
	-- recollir dades per a tractament estadstic:
	SELECT genere, modalitat, activitat INTO oldGenere, oldModalitat, oldActivitat
  	FROM JUGADOR
	WHERE id_jugador = paramID;

  IF (paramActivitat IS NOT NULL) THEN
    IF (paramActivitat NOT IN('ACTIU','RETIRAT')) THEN
      MSG_EX := 'ACTIVITAT pot prendre valors: ACTIU o RETIRAT';
      RAISE ERR_EX;    
    END IF;
    
    UPDATE JUGADOR SET activitat = paramActivitat   
    WHERE id_jugador = paramID;
  END IF;

-- modificaci del atribut ESTAT com a conseqncia d'un canvi en l'estat del jugador:  
  IF (paramEstat IS NOT NULL) THEN
    IF (paramEstat NOT IN('ALTA','BAIXA')) THEN
      MSG_EX := 'ESTAT pot prendre valors: ALTA o BAIXA';
      RAISE ERR_EX;    
    END IF;
    
    UPDATE JUGADOR SET estat = paramEstat   
    WHERE id_jugador = paramID;
  END IF;

-- actualitza dades estadstiques:
  IF (oldActivitat = 'ACTIU' AND paramActivitat = 'RETIRAT') THEN
	act_EST_81 (oldGenere, oldModalitat, '-', RSP);
  END IF;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades JUGADOR actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Jugador ; 
/