/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:			ins_Contracte
@Funcionalitat:	Afegir un nou contracte a la BD.
@params IN:		paramJugador NUMBER, 
				paramDataIni DATE,
				paramEquipC NUMBER,	 
				paramEquipV NUMBER,
				paramDurada NUMBER,
				paramUnitat VARCHAR2(1),
				paramSalariBrut NUMBER,
				paramClausula, NUMBER,
				paramDivisa VARCHAR2(3),
@params OUT:		paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text 	VARCHAR2(512);
@return			RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE ins_Contracte 
(
  paramJugador 		IN CONTRACTE.jugador%TYPE, 
  paramDataIni		IN CONTRACTE.data_inici%TYPE, 
  paramEquipC		IN CONTRACTE.equipC%TYPE, 
  paramEquipV		IN CONTRACTE.equipV%TYPE, 
  paramDurada		IN CONTRACTE.durada%TYPE, 
  paramUnitat		IN CONTRACTE.unitat%TYPE, 
  paramSalariBrut	IN CONTRACTE.salariBrut%TYPE, 
  paramClausula		IN CONTRACTE.clausula%TYPE, 
  paramDivisa   	IN CONTRACTE.divisa%TYPE,
  
  RSP 			OUT NOCOPY VARCHAR2
)
AS
    
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);  
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;
  
  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
  
  existeix 	INTEGER; 	 
  situ		VARCHAR2(7);
  varTemp 	VARCHAR2(9);
  varTemp2 	VARCHAR2(9);
  varModalitat VARCHAR2(15);
  varGenere VARCHAR2(1);
  varPais	VARCHAR2(20);
	 	 
BEGIN
RSP := 'KO';
procediment := 'ins_Contracte'; 
paramEntrada := 'Jugador: ' || paramJugador || 
          ' - Data: ' || paramDataIni||
          ' - Equip comprador: ' || paramEquipC || 
          ' - Equip venedor: ' || paramEquipV ||   
          ' - Durada: ' || paramDurada ||
          ' - Salari brut: ' || paramSalariBrut ||
          ' - Clausula: ' || paramClausula ||
          ' - Divisa ' || paramDivisa ;
          
    -- comprovar dades d'entrada:   
	IF (paramJugador IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp JUGADOR.';
		RAISE ERR_NN;
    ELSE
      SELECT COUNT(*) INTO existeix
      FROM JUGADOR
      WHERE id_jugador = paramJugador;
      
      IF (existeix = 0) THEN
        MSG_EX := 'Ldentificador del jugador no existeix a la BD.';
        RAISE ERR_EX;
      END IF;
	END IF;
  IF (paramDataIni IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp DATA.';
		RAISE ERR_NN;
    ELSIF (TO_CHAR(paramDataIni,'MM') != 7 
      OR (TO_CHAR(paramDataIni,'MM') = 7 AND TO_CHAR(paramDataIni,'DD') != 1)) THEN
      MSG_EX := 'La data dinici ha de ser 01-07-YYYY';
      RAISE ERR_EX;
  END IF;
	IF (paramEquipC IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp EQUIP.';
		RAISE ERR_NN;
    ELSE
      SELECT COUNT(*) INTO existeix
      FROM EQUIP
      WHERE id_equip = paramEquipC;
      
      IF (existeix = 0) THEN
        MSG_EX := 'Ldentificador de lequip no existeix a la BD.';
        RAISE ERR_EX;
      END IF;
	END IF;
  IF (paramDurada IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp DURADA.';
		RAISE ERR_NN;
    ELSIF (paramUnitat IS NULL) THEN
      MSG_NN := 'Cal emplenar el camp UNITAT.';
      RAISE ERR_NN;
      ELSIF (paramUnitat NOT IN('A','M','D')) THEN
        MSG_EX := 'Cal indicar anys(A), mesos(M) o dies(D)';
        RAISE ERR_EX;      
	END IF;
  IF (paramSalariBrut IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp SALARI BRUT.';
		RAISE ERR_NN;
    ELSIF (paramDivisa IS NULL) THEN
      MSG_NN := 'Cal emplenar el camp DIVISA.';
      RAISE ERR_NN;
      ELSE
        SELECT COUNT(*) INTO existeix
        FROM DIVISA
        WHERE id_divisa = paramDivisa;
        
        IF (existeix = 0) THEN
          MSG_EX := paramDivisa || ' no existeix a la BD.';
          RAISE ERR_EX;
        END IF;
	END IF;
  IF (paramClausula IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp CLAUSULA.';
		RAISE ERR_NN;	
	END IF;
	
	-- comprova si el jugador existeix i, en cas afirmatiu, si est en activitat = ACTIU:
	SELECT COUNT (*) INTO existeix
	FROM JUGADOR
    WHERE ID_JUGADOR = paramJugador 
		AND activitat = 'ACTIU';

	IF (existeix = 0) THEN
		MSG_EX := paramJugador || ' no existeix a la BD, o est retirat.';
		RAISE ERR_EX;
	END IF;
	
	-- comprova si lequip comprador existeix:
	SELECT COUNT (*) INTO existeix
	FROM EQUIP
     WHERE ID_EQUIP = paramEquipC ;

	IF (existeix = 0) THEN
		MSG_EX := paramEquipC || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

	-- comprova si lequip venedor existeix:
	IF (paramEquipV is not NULL) THEN
		SELECT COUNT (*) INTO existeix
		FROM EQUIP
		WHERE ID_EQUIP = paramEquipV ;
		END IF;
	
		IF (existeix = 0) THEN
			MSG_EX := paramEquipV || ' no existeix a la BD.';
			RAISE ERR_EX;
		END IF;
		
	-- comprova si el jugador t altres contractes vigents
	SELECT count(*) INTO existeix
	FROM CONTRACTE
	WHERE jugador = paramJugador 
		AND data_fi > paramDataIni;
	
	IF (existeix > 0) THEN
		MSG_EX := paramJugador || ' t un altre contracte encara vigent.';
		RAISE ERR_EX;
	END IF;

-- INSERT del nou contracte
INSERT INTO CONTRACTE VALUES ('', paramJugador, paramDataIni, paramEquipC, paramEquipV, paramDurada, paramUnitat, '', paramSalariBrut, paramClausula, '', paramDivisa);

-- dades per a tractament estadistic:
varTemp := to_char(EXTRACT(year from paramDataIni)) || '-' || to_char(EXTRACT(year from paramDataIni) + 1);
SELECT nacionalitat, modalitat, genere INTO varPais, varModalitat, varGenere
FROM JUGADOR
WHERE id_jugador = paramJugador;

COMMIT;
-- actualitza el jugador ms ben pagat segons gnere i modalitat:
act_EST_83(varModalitat, varGenere, paramJugador, paramSalariBrut, RSP);
-- actualitza el jugador amb ms guanys de la histria:
act_EST_84(RSP);
-- actualitza el souMig segons pas, temporada,, gnere i modalitat:
FOR comptador IN 0..paramDurada-1 LOOP
  -- Instruccions a realitzar paramDurada vegades:
  varTemp2 := to_char(substr(varTemp,1,4)+comptador) || '-' || to_char(substr(varTemp,6,9)+comptador);
  act_EST_85(varPais, varTemp2, varGenere, varModalitat, RSP); 
END LOOP;

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta CONTRACTE realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Contracte ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:			del_Contracte
@Funcionalitat:	Eliminar un contracte de la BD.
@params IN:		paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text 	VARCHAR2(512);
@return			RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE del_Contracte 
(
  paramID	IN CONTRACTE.id_contracte%TYPE,
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;
  
  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix 	INTEGER;
  varAny	NUMBER;
  VarTemp   VARCHAR2(9);
  varPais	VARCHAR2(30);
  varModalitat VARCHAR2(15);
  varGenere VARCHAR2(1);
  varJugador NUMBER;
  oldSalari NUMBER;
    
BEGIN
  RSP := 'KO';
  procediment := 'del_Contracte'; 
  paramEntrada := 'ID_CONTRACTE' || paramID;

-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador del contracte.';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM CONTRACTE
  WHERE id_contracte = paramID;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- dades per a tractament estadistic:  
  SELECT EXTRACT(year from c.data_inici), c.salariBrut, j.modalitat, j.genere, j.nacionalitat 
  INTO varAny, oldSalari, varModalitat, varGenere, varPais 
  FROM CONTRACTE c, JUGADOR j
  WHERE c.id_contracte = paramID AND j.id_jugador = c.jugador;

-- dades per a tractament estadstic:
varTemp := TO_CHAR(varAny) || '-' || TO_CHAR(varAny + 1);  

-- elimina CONTRACTE:    
  DELETE FROM CONTRACTE
  WHERE id_contracte = paramID;

COMMIT;
-- actualitza dades estadstiques:
act_EST_83(varModalitat, varGenere, varJugador, -oldSalari, RSP);
-- actualitza el jugador amb ms guanys de la histria:
act_EST_84(RSP);
-- actualitza el souMig segons pas, temporada,, gnere i modalitat:
act_EST_85(varPais, varTemp, varGenere, varModalitat, RSP);

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - CONTRACTE eliminat de la BD.' );

  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || procediment || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
 
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Contracte ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Contracte
@Funcionalitat:		Modificar la durada i/o dades econmiques del contracte.
@params IN:		paramID NUMBER, 
				paramDurada NUMBER,
				paramSalariBrut NUMBER,
				paramClausula NUMBER,
@params OUT:		paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text 	VARCHAR2(512);
@return			RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE upd_Contracte 
(
  paramID			IN CONTRACTE.id_contracte%TYPE,
  paramDurada		IN CONTRACTE.durada%TYPE,
  paramSalariBrut	IN CONTRACTE.salariBrut%TYPE,
  paramClausula		IN CONTRACTE.clausula%TYPE,
  paramDivisa		IN CONTRACTE.divisa%TYPE,
  
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix 	INTEGER;
  inici		DATE;
  AMD  VARCHAR2(1);
  fi DATE;
  oldSalari	NUMBER;  
  oldClausula	NUMBER;
  varAny		NUMBER;
  varPais VARCHAR2(20);
  varTemp	VARCHAR2(9);
  varModalitat VARCHAR2(15);
  varGenere VARCHAR2(1);
  varJugador NUMBER;
  

BEGIN
  RSP := 'KO';
  procediment := 'upd_Contracte'; 
  paramEntrada := 'ID_CONTRACTE' || paramID ||
				' - Durada: ' || paramDurada ||
				' - Salari brut; ' || paramSalariBrut ||
				' - Clausula: ' || paramClausula ||
				' - Divisa: ' || paramDivisa;
				 
-- comprovar dades d'entrada   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador del contracte.';
	RAISE ERR_NN;
    -- comprovar si existeix en la BD   
    ELSE
      SELECT count(*) INTO existeix 
      FROM CONTRACTE
      WHERE id_contracte = paramID;

      IF (existeix = 0) THEN
        MSG_EX := paramID || ' no existeix a la BD.';
        RAISE ERR_EX;
      END IF;
  END IF;
  
  IF ((paramDurada IS NULL)
      AND (paramSalariBrut IS NULL)
        AND (paramClausula IS NULL)
          AND (paramDivisa IS NULL)) THEN
    MSG_NN := 'No has entrat cap dada a modificar!';
    RAISE ERR_NN;
  END IF;

 
 -- dades per a tractament estadistic:  
  SELECT EXTRACT(year from c.data_inici), c.salariBrut, j.id_jugador, j.nacionalitat, j.modalitat, j.genere 
  INTO varAny, oldSalari, varJugador, varPais, varModalitat, varGenere 
  FROM CONTRACTE c, JUGADOR j
  WHERE c.id_contracte = paramID AND j.id_jugador = c.jugador;
 
-- modificaci de la durada del contracte  
  IF (paramDurada IS NOT NULL) THEN
    SELECT data_inici, unitat INTO inici, amd
    FROM CONTRACTE
    WHERE id_contracte = paramID;
      
      IF (amd = 'A') THEN
        fi := inici + paramDurada * 365;
      ELSIF (amd = 'M') THEN
        fi := inici + paramDurada * 30;
      ELSIF (amd = 'D') THEN
        fi := inici + paramDurada;
      END IF;
    
    UPDATE CONTRACTE SET durada = paramDurada, data_fi = fi 
    WHERE id_contracte = paramID;
  END IF;
  
-- comprova si la divisa existeix
  IF (paramDivisa IS NOT NULL) THEN
    SELECT count(*) INTO existeix 
    FROM DIVISA
    WHERE nom = paramDivisa;

    IF (existeix = 0) THEN
      MSG_EX := paramDivisa || ' no existeix a la BD.';
      RAISE ERR_EX;
    END IF;	
  END IF;
  
-- una modificaci del salari brut repercuteix en el valor del contracte  
	IF (paramSalariBrut IS NOT NULL) THEN
		-- modifica el salariBrut i el valor:
		UPDATE CONTRACTE SET salariBrut = paramSalariBrut, valor = valor - oldSalari + paramSalariBrut 
		WHERE id_contracte = paramID;
		
		COMMIT;
		-- dades per a tractament estadstic:
		varTemp := to_char(varAny) || '-' || to_char(varAny + 1);  
		
		-- actualitza el souMig segons pas, temporada,, gnere i modalitat:
		act_EST_85(varPais, varTemp, varGenere, varModalitat, RSP);
	END IF;	
  
-- una modificaci de la clausula repercuteix en el valor del contracte
	IF (paramClausula IS NOT NULL) THEN
    SELECT clausula INTO oldClausula
    FROM CONTRACTE
    WHERE id_contracte = paramID;
  
		UPDATE CONTRACTE SET clausula = paramClausula, valor = valor - oldClausula + paramClausula 
		WHERE id_contracte = paramID;
	END IF;	
	
COMMIT;	
-- actualitza dades estadstiques:
act_EST_83(varModalitat, varGenere, varJugador, paramSalariBrut-oldSalari, RSP);
-- actualitza el jugador amb ms guanys de la histria:
act_EST_84(RSP);

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades del CONTRACTE actualizades a la BD.' );

  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Contracte ;
/