/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:			ins_Partit
@Funcionalitat:	Afegir un nou partit a la BD. Per defecte s'assigna estat = 'P' (previst).
@params IN:		paramDiaHora TIMESTAMP, 
				paramMunicipi VARCHAR2(20 CHAR),	 
				paramPavello VARCHAR2(20 CHAR),
				paramEqLocal NUMBER,
				paramEqVisitant NUMBER,
				paramCompeticio NUMBER,
				paramEstat VARCHAR2(1),
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
@return			RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE ins_Partit 
(
  paramDiaHora		IN PARTIT.dia_hora%TYPE, 
  paramMunicipi		IN PARTIT.municipi%TYPE, 
  paramPavello		IN PARTIT.pavello%TYPE, 
  paramEqLocal		IN PARTIT.eqLocal%TYPE, 
  paramEqVisitant	IN PARTIT.eqVisitant%TYPE, 
  paramCompeticio	IN PARTIT.competicio%TYPE, 
  paramEstat		IN PARTIT.estat%TYPE, 
  
  RSP 			OUT NOCOPY VARCHAR2
)
AS
    
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
  
  existeix 	INTEGER; 	 
	 
BEGIN
RSP := 'KO';
procediment := 'ins_Partit'; 
paramEntrada := 'Data: ' || paramDiaHora ||
          ' - Municipi: ' || paramMunicipi || 
          ' - Pavell: ' || paramPavello || 
          ' - Equip local: ' || paramEqLocal || 
          ' - Equip visitant: ' || paramEqVisitant ||   
          ' - Competicio: ' || paramCompeticio ||
          ' - Estat: ' || paramEstat ;
           
-- comprovar dades d'entrada:   
	IF (paramEqLocal IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp EQUIP LOCAL.';
		RAISE ERR_NN;
    ELSE
      SELECT COUNT(*) INTO existeix
      FROM EQUIP
      WHERE id_equip = paramEqLocal;
      
      IF (existeix = 0) THEN
        MSG_EX := 'Equip inexistent.';
        RAISE ERR_EX;
      END IF;
	END IF;
	IF (paramEqVisitant IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp EQUIP VISITANT.';
		RAISE ERR_NN;
    ELSE
      SELECT COUNT(*) INTO existeix
      FROM EQUIP
      WHERE id_equip = paramEqVisitant;
      
      IF (existeix = 0) THEN
        MSG_EX := 'Equip inexistent.';
        RAISE ERR_EX;
      END IF;
      
      IF (paramEqLocal = paramEqVisitant) THEN
        MSG_EX := 'Cal introduir dos equips diferents!';
        RAISE ERR_EX;
      END IF;
	END IF;
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp COMPETICIO.';
		RAISE ERR_NN;
    ELSE
      SELECT COUNT(*) INTO existeix
      FROM COMPETICIO
      WHERE id_competicio = paramCompeticio;
      
      IF (existeix = 0) THEN
        MSG_EX := 'Competici inexistent.';
        RAISE ERR_EX;
      END IF;
	END IF;
  IF (paramEstat IS NULL) THEN
    MSG_NN := 'Cal emplenar el camp ESTAT.';
    RAISE ERR_NN;
    ELSIF (paramEstat NOT IN('P','I','F')) THEN
      MSG_EX := 'ESTAT pot prendre valors: PROGRAMAT(P), INICIAT(I), FINALITZAT(Z)';
      RAISE ERR_EX;
  END IF;
  
-- comprova si el partit ja existeix:
  SELECT COUNT(*) INTO existeix
  FROM PARTIT
  WHERE eqLocal = paramEqLocal AND eqVisitant = paramEqVisitant AND competicio = paramCompeticio;
  
  IF (existeix = 1) THEN
    MSG_EX := 'Aquest partit ja existeix a la BD.';
    RAISE ERR_EX;
  END IF;
	
-- INSERT del nou partit
INSERT INTO PARTIT VALUES ('', paramDiaHora, paramMunicipi, paramPavello, paramEqLocal, paramEqVisitant, paramCompeticio, paramEstat);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta PARTIT realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
   
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Partit ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Partit
@Funcionalitat:		Eliminar un partit de la BD.
@restriccions:		Cal que l'estat del partit sigui 'P' = previst.
@params IN:		paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
@return			RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE del_Partit 
(
  paramID	IN PARTIT.id_partit%TYPE,
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix 	INTEGER;
  estLocal		VARCHAR2(1);
  
BEGIN
  RSP := 'KO';
  procediment := 'del_Partit'; 
  paramEntrada := 'ID_PARTIT' || paramID;

-- comprovar dades d'entrada   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador del partit.';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD   
  SELECT count(*) INTO existeix 
  FROM PARTIT
  WHERE id_partit = paramID;

  IF (existeix = 0) THEN
	MSG_EX := 'El partit ' || paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- comprova si s'ha iniciat
  SELECT estat INTO estLocal 
  FROM PARTIT
  WHERE id_partit = paramID;

  IF (estLocal != 'P') THEN
	MSG_EX := 'El partit ' || paramID || ' ja ha comenat i/o acabat.';
	RAISE ERR_EX;
  END IF;

-- Eliminar el partit de la BD    
  DELETE FROM PARTIT WHERE Partit.id_partit = paramID;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - PARTIT eliminat de la BD.' );

  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Partit ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Partit
@Funcionalitat:		Modificar la data i/o lloc on s'ha de jugar el partit, o l'estat: 'I' = iniciat, 'F' = f.
@restriccions:		Per poder modificar la data o el lloc, cal que l'estat del partit sigui 'P' = previst. 
@params IN:		paramID NUMBER, 
				paramDH TIMESTAMP(0)
				paramMunicipi VARCHAR2(20)
				paramPavello VARCHAR2(20)
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE upd_Partit 
(
  paramID	IN PARTIT.id_partit%TYPE,
  paramDH	IN PARTIT.dia_hora%TYPE,
  paramMunicipi	IN PARTIT.municipi%TYPE,
  paramPavello	IN PARTIT.pavello%TYPE,
  paramEstat	IN PARTIT.estat%TYPE,
  
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix 	INTEGER;
  estLocal		VARCHAR2(1);
  
BEGIN
  RSP := 'KO';
  procediment := 'upd_Partit'; 
  paramEntrada := 'ID_PARTIT' || paramID ||
				' - Dia i hora: ' || paramDH ||
				' - Municipi; ' || paramMunicipi ||
				' - Pavello: ' || paramPavello ||
				' - Estat: ' || paramEstat ;

  IF ((paramDH IS NULL)
    AND (paramMunicipi IS NULL)
      AND (paramPavello IS NULL)
        AND (paramEstat IS NULL)) THEN
    MSG_EX := 'No has entrat cap dada a modificar!';
    RAISE ERR_EX;
  END IF;

-- comprovar dades d'entrada   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador del PARTIT.';
	RAISE ERR_NN;
    ELSE
      SELECT COUNT(*) INTO existeix
      FROM PARTIT
      WHERE id_partit = paramID;
      
      IF (existeix = 0) THEN
        MSG_EX := 'Lidentificador del partit no existeix a la BD.';
        RAISE ERR_EX;
      END IF;
  END IF;
  
IF ((paramDH IS NULL)
    AND (paramMunicipi IS NULL)
      AND (paramPavello IS NULL)
        AND (paramEstat IS NULL)) THEN
    MSG_EX := 'No has entrat cap dada a modificar!';
    RAISE ERR_EX;
  END IF;  

-- modificar lestat del partit ('P','I','F')
  IF (paramEstat IS NOT NULL) THEN
    IF (paramEstat NOT IN('P','I','F')) THEN
      MSG_EX := 'ESTAT pot prendre valors: PROGRAMAT(P), INICIAT(I), FINALITZAT(Z)';
      RAISE ERR_EX;
    END IF;
    
    SELECT estat INTO estLocal
    FROM PARTIT
    WHERE id_partit = paramID;  
    
    IF ((estLocal = 'P' AND paramEstat != 'P') 
      OR (estLocal = 'I' AND paramEstat = 'F')) THEN
      UPDATE PARTIT SET estat = paramEstat WHERE id_partit = paramID;
    ELSE
      MSG_EX := 'Aquest canvi no s possible!';
      RAISE ERR_EX;
    END IF;  
    
  END IF;
  
-- Modificar la data, el municipi o el pavello en el es jugar el partit.    
  IF (paramDH IS NOT NULL) THEN
    UPDATE PARTIT SET dia_hora = paramDH
    WHERE id_partit = paramID;
  END IF;
	
  IF (paramMunicipi IS NOT NULL) THEN
    UPDATE PARTIT SET municipi = paramMunicipi
    WHERE id_partit = paramID;
  END IF;
  
  IF (paramPavello IS NOT NULL) THEN
    UPDATE PARTIT SET pavello = paramPavello		   
    WHERE id_partit = paramID;
  END IF;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades PARTIT actualitzades a la BD.' );

  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Partit ;
/
