/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:			ins_Equip
@Funcionalitat:	Afegir un nou equip a la BD.
@params IN:		paramNom VARCHAR2(20 CHAR), 
				paramAdreca VARCHAR2(40 CHAR), 
				paramMunicipi VARCHAR2(25 CHAR), 
				paramPais VARCHAR2(20 CHAR),
				paramTelefon VARCHAR2(20 CHAR), 
				paramJuridic VARCHAR2(4 CHAR), 
				paramUrl VARCHAR2(40 CHAR), 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE ins_Equip 
(
  paramNom 		IN EQUIP.nom%TYPE, 
  paramAdreca		IN EQUIP.adreca%TYPE, 
  paramMunicipi		IN EQUIP.municipi%TYPE, 
  paramPais		IN EQUIP.pais%TYPE,
  paramTelefon		IN EQUIP.telefon%TYPE, 
  paramJuridic		IN EQUIP.formaJuridica%TYPE, 
  paramUrl 		IN EQUIP.url%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
 
  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);

BEGIN
RSP := 'KO';
procediment := 'ins_Equip'; 
paramEntrada := 'Nom: ' || paramNom ||
		' - Adrea: ' || paramAdreca ||
		' - Municipi: ' || paramMunicipi ||
		' - Pas: ' || paramPais ||	
		' - Telefon: ' || paramTelefon ||		
		' - CLUB | SAD: ' || paramJuridic ||	
		' - URL: ' || paramUrl ;	

-- comprovar dades d'entrada:   
	IF (paramNom IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NOM.';
		RAISE ERR_NN;
	END IF;
	IF (paramPais IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp PAIS.';
		RAISE ERR_NN;
	END IF;
	IF (paramJuridic IS NULL) THEN
		MSG_NN := 'Cal indicar si lequip s un club o una SAD.';
		RAISE ERR_NN;
	END IF;

-- INSERT del nou equip
INSERT INTO EQUIP VALUES ('', paramNom, paramAdreca, paramMunicipi, paramPais, paramTelefon, paramJuridic, paramURL);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta EQUIP realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Equip ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:			del_Equip
@Funcionalitat:	Eliminar un equip de la BD.
@restriccions	No es pot eliminar un equip que t contractes amb algun jugador
@params IN		paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE del_Equip 
(
  paramID	IN EQUIP.id_equip%TYPE,
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
  oldGenere VARCHAR2(2);
  oldModalitat VARCHAR2(15);
    
BEGIN
  RSP := 'KO';
  procediment := 'del_Equip'; 
  paramEntrada := 'ID_EQUIP' || paramID;

-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de lequip';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM Equip
  WHERE id_equip = paramID;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- comprova si t contractes
  SELECT count(*) INTO existeix
  FROM Contracte
  WHERE (equipC = paramID OR equipV = paramID);
	
  IF (existeix > 0) THEN
	MSG_EX := 'Existeixen contractes amb jugadors per a aquest equip: ' || paramID;
	RAISE ERR_EX;
  END IF;
	    
  DELETE FROM Equip
  WHERE Equip.id_equip = paramID;
-- resultat BAIXA: CORRECTA

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - EQUIP eliminat de la BD.' );

  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Equip ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Equip
@Funcionalitat:		Modificar un dels atributs de l'equip
@param:			paramID NUMBER,
				paramAdreca VARCHAR2(40), 
				paramMunicipi VARCHAR2(25), 
				paramPais VARCHAR2(20),
				paramTelefon VARCHAR2(20), 
				paramJuridic VARCHAR2(4), 
				paramUrl VARCHAR2(40), 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE upd_Equip 
(
  paramID			IN EQUIP.id_equip%TYPE,
  paramNom 		IN EQUIP.nom%TYPE,
  paramAdreca 		IN EQUIP.adreca%TYPE,
  paramMunicipi  	IN EQUIP.municipi%TYPE,
  paramPais		IN EQUIP.pais%TYPE,
  paramTelefon		IN EQUIP.pais%TYPE,
  paramJuridic		IN EQUIP.formaJuridica%TYPE,
  paramUrl			IN EQUIP.url%TYPE,
 
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(56);
  MSG_NN 	VARCHAR2(25);
  MSG_EX 	VARCHAR2(25);

  existeix 	INTEGER;
  varLocal		VARCHAR2(40);
  
BEGIN
  RSP := 'KO';
  procediment := 'upd_Equip'; 
  paramEntrada := 'ID_EQUIP' || paramID ||
		' - Nom: ' || paramNom ||
		' - Adrea: ' || paramAdreca ||
		' - Municipi: ' || paramMunicipi ||
		' - Pas: ' || paramPais ||	
		' - Telefon: ' || paramTelefon ||		
		' - CLUB | SAD: ' || paramJuridic ||	
		' - URL: ' || paramUrl ;	

-- comprovar dades d'entrada   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de lequip.';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD   
  SELECT count(*) INTO existeix 
  FROM EQUIP
  WHERE id_equip = paramID;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a taula POSICIO de la BD.';
	RAISE ERR_EX;
  END IF;

-- Corregir o completar algun dels atributs inicials.  
  SELECT nom INTO varLocal FROM EQUIP WHERE id_equip = paramID;
  IF (varLocal != paramNom) THEN
	UPDATE EQUIP SET nom = paramNom
	WHERE id_equip = paramID;
  END IF;
	
  SELECT adreca INTO varLocal FROM EQUIP WHERE id_equip = paramID;
  IF (varLocal != paramAdreca) THEN
	UPDATE EQUIP SET adreca = paramAdreca
	WHERE id_equip = paramID;
  END IF;
  
  SELECT municipi INTO varLocal FROM EQUIP WHERE id_equip = paramID;
  IF (varLocal != paramMunicipi) THEN
	UPDATE EQUIP SET municipi = paramMunicipi 
	WHERE id_equip = paramID;
  END IF;
	
  SELECT pais INTO varLocal FROM EQUIP WHERE id_equip = paramID;
  IF (varLocal != paramPais) THEN
	UPDATE EQUIP SET pais = paramPais   
	WHERE id_equip = paramID;
  END IF;
  
  SELECT telefon INTO varLocal FROM EQUIP WHERE id_equip = paramID;
  IF (varLocal != paramTelefon) THEN
	UPDATE EQUIP SET telefon = paramTelefon  
	WHERE id_equip = paramID;
  END IF;

  SELECT URL INTO varLocal FROM EQUIP WHERE id_equip = paramID;
  IF (varLocal != paramUrl OR varLocal IS NULL) THEN
	UPDATE EQUIP SET url = paramUrl   
	WHERE id_equip = paramID;
  END IF;
  
-- resultat MODIFICACIO: CORRECTE
RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades EQUIP actualitzades a la BD.' );

  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Equip ;  
/
