/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:			ins_Entrenador
@Funcionalitat:	Afegir un nou entrenador a la BD
@params IN:		paramNom VARCHAR2(20 CHAR), 
				paramCognom1 VARCHAR2(20 CHAR),
				paramCognom2 VARCHAR2(20 CHAR),
				paramTelefon VARCHAR2(20 CHAR),
				paramRol VARCHAR2(20 CHAR),					
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE ins_Entrenador 
(
  paramNom 		IN ENTRENADOR.nom%TYPE, 
  paramCognom1		IN ENTRENADOR.cognom1%TYPE, 
  paramCognom2		IN ENTRENADOR.cognom2%TYPE, 
  paramTelefon 		IN ENTRENADOR.telefon%TYPE,
  paramRol			IN ENTRENADOR.titol%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);

BEGIN
RSP := 'KO';
procediment := 'ins_Entrenador'; 
paramEntrada := 'Nom: ' || paramNom || 
          ' - Cognom1: ' || paramCognom1 ||
          ' - Cognom2: ' || paramCognom2 ||
          ' - Telefon: ' || paramTelefon ||
          ' - Rol: ' || paramRol;	

-- comprovar dades d'entrada:   
	IF (paramNom IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NOM.';
		RAISE ERR_NN;
	ELSIF (paramCognom1 IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp Cognom1.';
		RAISE ERR_NN;
	END IF;

-- INSERT d'un nou entrenador
INSERT INTO ENTRENADOR VALUES ('', paramNom, paramCognom1, paramCognom2, paramTelefon, paramRol);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta ENTRENADOR realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
   
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Entrenador ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Entrenador
@Funcionalitat:		Eliminar un entrenador de la BD
@restriccions		No es pot eliminar si ha estat, al menys, entrenador dun equip.
@params IN			paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE del_Entrenador 
(
  paramID	IN ENTRENADOR.id_entrenador%TYPE,
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;
  
  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
  
  existeix INTEGER;
      
BEGIN
  RSP := 'KO';
  procediment := 'del_Entrenador'; 
  paramEntrada := 'ID_ENTRENADOR' || paramID;

-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de lentrenador';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM Entrenador
  WHERE id_entrenador = paramID;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- comprova si entrena o ha entrenat cap equip:
  SELECT count(*) INTO existeix
  FROM Equip_tecnic
  WHERE entrenador = paramID;
	
	IF (existeix > 0) THEN
		MSG_EX := paramID || ' consta com a entrenador dun equip.';
		RAISE ERR_EX;
	END IF;

-- elimina l'entrenador de la BD:    
  DELETE FROM Entrenador WHERE entrenador.id_entrenador = paramID;
-- resultat BAIXA: CORRECTE

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - ENTRENADOR eliminat de la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Entrenador ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Entrenador
@Funcionalitat:		Modificar un dels atributs d'un entrenador
@param:			
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE upd_Entrenador 
(
  paramID		IN ENTRENADOR.id_entrenador%TYPE,
  paramTelefon	IN ENTRENADOR.telefon%TYPE,
  paramTitol	IN ENTRENADOR.titol%TYPE,
    
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix 	INTEGER;
    
BEGIN
  RSP := 'KO';
  procediment := 'upd_Entrenador'; 
  paramEntrada := 'ID_ENTRENADOR' || paramID ||
				' - Telefon: ' || paramTelefon ||
				' - Rol: ' || paramTitol ;
				
-- comprovar dades d'entrada   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de lentrenador';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD   
  SELECT count(*) INTO existeix 
  FROM ENTRENADOR
  WHERE id_entrenador = paramID;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- Corregir o modificar algun dels atributs inicials.    
  IF (paramTelefon IS NOT NULL) THEN
	UPDATE ENTRENADOR SET telefon = paramTelefon
	WHERE id_entrenador = paramID;
  END IF;
	
  IF (paramTitol IS NOT NULL) THEN
	UPDATE ENTRENADOR SET titol = paramTitol
	WHERE id_entrenador = paramID;
  END IF;
    
-- resultat MODIFICACIO: CORRECTE
RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades ENTRENADOR actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Entrenador ;
/
