/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Representant
@Funcionalitat:		Afegir un nou representant de jugadors a la BD.
@params IN:		paramNom VARCHAR2(25 CHAR), 
				paramTelefon VARCHAR2(20 CHAR),					
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE ins_Representant 
(
  paramNom 		IN REPRESENTANT.nom%TYPE, 
  paramTelefon 		IN REPRESENTANT.telefon%TYPE,

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);

BEGIN
RSP := 'KO';
procediment := 'ins_Representant'; 
paramEntrada := 'Nom: ' || paramNom || 
          ' - Telefon: ' || paramTelefon;	

-- comprovar dades d'entrada:   
	IF (paramNom IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NOM.';
		RAISE ERR_NN;
	END IF;

-- INSERT del nou representant
INSERT INTO REPRESENTANT VALUES ('', paramNom, paramTelefon);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta REPRESENTANT realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Representant ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Representant
@Funcionalitat:		Eliminar un representant de la BD
@restriccions		No es pot eliminar si ha representat, al menys, a un jugador.
@params IN			paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE del_Representant
(
  paramID	IN REPRESENTANT.id_representant%TYPE,
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;
 
  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
    
BEGIN
  RSP := 'KO';
  procediment := 'del_Representant'; 
  paramEntrada := 'ID_REPRESENTANT: ' || paramID;

-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador del representant.';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM REPRESENTANT
  WHERE id_representant = paramID;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- comprova si t contractes
  SELECT count(*) INTO existeix
  FROM REP_JUGADOR
  WHERE representant = paramID;
	
  IF (existeix > 0) THEN
	MSG_EX := paramID || ' s o ha estat representant de jugadors.';
	RAISE ERR_EX;
  END IF;

-- elimina el representant    
  DELETE FROM REPRESENTANT WHERE id_representant = paramID;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades REPRESENTANT actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Representant ;
/
