/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Rep_Jugador
@Funcionalitat:		Afegir una relaci entre un jugador i un representant a la BD.
@restriccions:		Si el jugador t un representant, per reflectir el canvi, s'assignar la data_inici de la nova relaci com a data-fi de l'anterior.
@params IN:		paramJugador NUMBER, 
				paramDataIni DATE,
				paramRepresentant NUMBER,
				paramDataFi DATE,					
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace 
PROCEDURE ins_Rep_Jugador 
(
  paramJugador 		IN REP_JUGADOR.jugador%TYPE, 
  paramDataIni		IN REP_JUGADOR.data_inici%TYPE, 
  paramRepresentant 	IN REP_JUGADOR.representant%TYPE,
  paramDataFi		IN REP_JUGADOR.data_fi%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;

BEGIN
RSP := 'KO';
procediment := 'ins_Rep_Jugador'; 
paramEntrada := 'Jugador: ' || paramJugador || 
          ' - Des de: ' || paramDataIni||
          ' - Representant: ' || paramRepresentant ||
          ' - Fins: ' || paramDataFi;	

-- comprovar dades d'entrada:   
	IF (paramJugador IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp JUGADOR.';
		RAISE ERR_NN;
	ELSIF (paramRepresentant IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp REPRESENTANT.';
		RAISE ERR_NN;
	ELSIF (paramDAtaIni IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp DES DE.';
		RAISE ERR_NN;
	END IF;

	-- comprovaci referncies: claus foranes
	SELECT COUNT (*) INTO existeix
	FROM JUGADOR
     WHERE ID_JUGADOR = paramJugador ;

	IF (existeix = 0) THEN
		MSG_EX := 'El jugador ' || paramJugador || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

	SELECT COUNT (*) INTO existeix
	FROM REPRESENTANT
     WHERE ID_REPRESENTANT = paramRepresentant ;

	IF (existeix = 0) THEN
		MSG_EX := 'El representant ' || paramRepresentant || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

	-- comprovar si el jugador t cap altre representant
	SELECT COUNT(*) 	INTO existeix
	FROM REP_JUGADOR
	WHERE jugador = paramJugador 
		AND representant = paramRepresentant
		AND data_fi is NULL ;

	IF (existeix > 0) THEN
		UPDATE REP_JUGADOR SET data_fi = paramDataIni 
		WHERE jugador = paramJugador
			AND representant = paramRepresentant
			AND data_fi is NULL ;
	END IF;

-- INSERT del nou representant
INSERT INTO REP_JUGADOR VALUES (paramJugador, paramDataIni, paramRepresentant, paramDataFi);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta REP_JUGADOR realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Rep_Jugador ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Rep_Jugador
@Funcionalitat:		Dona per acabada la relaci representant/jugador.
@restriccions		La data de finalitzaci ha de ser posterior a la data dinici de la representaci.
@params IN			paramJugador NUMBER, 
				paramRepresentant NUMBER,
				paramDataFi DATE,					
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE upd_Rep_Jugador 
(
  paramJugador 		IN REP_JUGADOR.jugador%TYPE, 
  paramRepresentant 	IN REP_JUGADOR.representant%TYPE,
  paramDataFi		IN REP_JUGADOR.data_fi%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX 	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
  lastDate	DATE;

BEGIN
RSP := 'KO';
procediment := 'upd_Rep_Jugador '; 
paramEntrada := 'Jugador: ' || paramJugador || 
          ' - Representant: ' || paramRepresentant ||
          ' - Fins: ' || paramDataFi;	

-- comprovar dades d'entrada:   
	IF (paramJugador IS NULL) THEN
		MSG_NN := 'Cal indicar lidentificador del JUGADOR.';
		RAISE ERR_NN;
	ELSIF (paramRepresentant IS NULL) THEN
		MSG_NN := 'Cal indicar lidentificador del REPRESENTANT.';
		RAISE ERR_NN;
	END IF;

-- comprova si existeix el jugador:
	SELECT COUNT (*) INTO existeix
	FROM JUGADOR
	WHERE ID_JUGADOR = paramJugador ;

		IF (existeix = 0) THEN
			MSG_EX := 'El jugador ' || paramJugador || ' no existeix a la BD.';
			RAISE ERR_EX;
		END IF;

-- comprova si existeix el representant:
	SELECT COUNT (*) INTO existeix
	FROM REPRESENTANT
	WHERE ID_REPRESENTANT = paramRepresentant ;

	IF (existeix = 0) THEN
		MSG_EX := 'El representant ' || paramRepresentant || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

-- cerca la data d'inici del darrer representant
	SELECT data_inici INTO lastDate
	FROM REP_JUGADOR
	WHERE JUGADOR = paramJugador 
		AND REPRESENTANT = paramRepresentant ;

-- comprovar que la dataFi s posterior a la dataInici:
	IF (lastDate < paramDataFi) THEN
		MSG_EX := 'La data de finalitzaci no pot ser anterior a la data dinici.';
		RAISE ERR_EX;
	END IF;
	
-- UPDATE sobre la dataFi de la darrera relaci entre jugador i representant
	UPDATE REP_JUGADOR SET data_fi = paramDataFi
	WHERE JUGADOR = paramJugador 
		AND REPRESENTANT = paramRepresentant 
		AND data_inici = lastDate ;

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades REPRESENTANT_JUGADOR actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Rep_Jugador  ;
/
