/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_EquipTecnic
@Funcionalitat:		Afegir un nou entrenador a l'equip tcnic.
@params IN:		paramEntrenador NUMBER, 
				paramDataIni VARCHAR2(20 CHAR),
				paramEquip NUMBER,
				paramOrdre VARCHAR2(20 CHAR),
				paramDurada NUMBER,					
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE ins_EquipTecnic
(
  paramEntrenador	IN ENTRENADOR.id_entrenador%TYPE, 
  paramDataIni		IN EQUIP_TECNIC.data_inici%TYPE, 
  paramEquip		IN EQUIP.id_equip%TYPE, 
  paramRol 		IN EQUIP_TECNIC.rol%TYPE,
  paramDurada		IN EQUIP_TECNIC.durada%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
  
  existeix 	INTEGER; 	 

BEGIN
RSP := 'KO';
procediment := 'ins_EquipTecnic'; 
paramEntrada := 'Entrenador: ' || paramEntrenador || 
          ' - Data inici: ' || paramDataIni ||
          ' - Equip: ' || paramEquip ||
          ' - Rol: ' || paramRol ||
          ' - Durada: ' || paramDurada;	

-- comprovar dades d'entrada:   
	IF (paramEntrenador IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp ENTRENADOR.';
		RAISE ERR_NN;
	ELSIF (paramDataIni IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp DATA.';
		RAISE ERR_NN;
	ELSIF (paramEquip IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp EQUIP.';
		RAISE ERR_NN;
	ELSIF (paramRol IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp ROL.';
		RAISE ERR_NN;
	END IF;

-- comprova si lentrenador existeix a la BD:
	SELECT COUNT (*) INTO existeix
	FROM ENTRENADOR
    WHERE ID_ENTRENADOR = paramEntrenador ;

		IF (existeix = 0) THEN
			MSG_EX := paramEntrenador || ' no existeix a la BD.';
			RAISE ERR_EX;
		END IF;

-- comprova si lequip existeix a la BD:
 	SELECT COUNT (*) INTO existeix
 	FROM EQUIP
 	WHERE ID_EQUIP = paramEquip ;

		IF (existeix = 0) THEN
			MSG_EX := paramEquip || ' no existeix a la BD.';
			RAISE ERR_EX;
		END IF;

-- comprova si el tcnic t un altre contracte en vigor:
	SELECT COUNT (*)
	INTO existeix
	FROM EQUIP_TECNIC
	WHERE ENTRENADOR = paramEntrenador 
		AND (data_inici + durada) > paramDataIni;
	
		IF (existeix > 0) THEN
			MSG_EX := paramEntrenador || ' t un altre contracte en vigor.';
			RAISE ERR_EX;
		END IF;

-- INSERT assignaci d'un entrenador a un equip
INSERT INTO EQUIP_TECNIC VALUES (paramEntrenador, paramDataIni, paramEquip, paramRol, paramDurada);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta EQUIP_TECNIC realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_EquipTecnic ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_EquipTecnic
@Funcionalitat:		Eliminar un component de l'equip tcnic.
@restriccions		
@params IN			paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE del_EquipTecnic 
(
  paramID	IN ENTRENADOR.id_entrenador%TYPE,
  RSP 		OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;
  ERR_EE	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
      
BEGIN
  RSP := 'KO';
  procediment := 'del_EquipTecnic'; 
  paramEntrada := 'ID_ENTRENADOR' || paramID;

-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de lentrenador';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM Entrenador
  WHERE id_entrenador = paramID;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- elimina lentrenador de lequip tcnic  
  DELETE FROM Entrenador WHERE entrenador.id_entrenador = paramID;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - EQUIP_TECNIC eliminat de la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_EquipTecnic ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_EquipTecnic
@Funcionalitat:		Modificar la durada que l'entrenador treballa amb lequip
@restriccions		El temps es pot modificar sobre una relaci en actiu.
@params IN:			paramID NUMBER, 
					paramDataIni DATE,
					paramDurada NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE upd_EquipTecnic
(
  paramID		IN EQUIP_TECNIC.entrenador%TYPE,
  paramDataIni	IN EQUIP_TECNIC.data_inici%TYPE, 
  paramEquip	IN EQUIP.id_equip%TYPE, 
  paramRol 		IN EQUIP_TECNIC.rol%TYPE,
  paramDurada	IN EQUIP_TECNIC.durada%TYPE, 
  
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
     
BEGIN
  RSP := 'KO';
  procediment := 'upd_EquipTecnic'; 
  paramEntrada := 'ID_ENTRENADOR' || paramID ||
				' Data inici: ' || paramDataIni ||
				' Equip: ' || paramEquip ||
				' Rol: ' || paramRol ||
				' Durada: ' || paramDurada ;
				  
-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal emplenar el camp ENTRENADOR.';
	RAISE ERR_NN;
  END IF;
  
  IF (paramDataIni IS NULL) THEN
	MSG_NN := 'Cal emplenar el camp DATA INICI.';
	RAISE ERR_NN;
  END IF;
  
  IF (paramEquip IS NULL) THEN
	MSG_NN := 'Cal emplenar el camp EQUIP.';
	RAISE ERR_NN;
  END IF;
  
  IF (paramRol IS NULL) THEN
	MSG_NN := 'Cal emplenar el camp ROL.';
	RAISE ERR_NN;
  END IF;
  
-- comprovar si l'entrenador existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM ENTRENADOR
  WHERE id_entrenador = paramID;

	IF (existeix = 0) THEN
		MSG_EX := paramID || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

-- comprova si l'entrenador t contracte en vigor
  SELECT count(*) INTO existeix
  FROM EQUIP_TECNIC
  WHERE entrenador = paramID
	AND data_inici = paramDataIni
	AND (data_inici + durada) > sysdate;
	
	IF (existeix = 0) THEN
		MSG_EX := paramID || ' no t contractes en vugor.';
		RAISE ERR_EX;
	END IF;

-- actualitza la durada    
  UPDATE EQUIP_TECNIC SET durada = paramDurada WHERE entrenador = paramID and data_inici = paramDataIni;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades EQUIP_TECNIC actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_EquipTecnic ;
/