/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Rep_Equip
@Funcionalitat:		Afegir una relaci entre un equip amb el seu representant a la BD.
@restriccions:		
@params IN:		paramEquip NUMBER, 
				paramDataIni DATE,
				paramRepresentant NUMBER,
				paramProtocol VARCHAR2(20 CHAR),					
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */    
create or replace PROCEDURE ins_Rep_Equip 
(
  paramEquip 		IN REP_EQUIP.equip%TYPE, 
  paramDataIni		IN REP_EQUIP.data_inici%TYPE, 
  paramRepresentant IN REP_EQUIP.repLegal%TYPE,
  paramProtocol		IN REP_EQUIP.protocol%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;

BEGIN
RSP := 'KO';
procediment := 'ins_Rep_Equip'; 
paramEntrada := 'Equip: ' || paramEquip || 
          ' - Des de: ' || paramDataIni||
          ' - Representant legal: ' || paramRepresentant ||
          ' - Protocol: ' || paramProtocol;	

-- comprovar dades d'entrada:   
	IF (paramEquip IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp EQUIP.';
		RAISE ERR_NN;
  END IF;
  
	IF (paramRepresentant IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp REPRESENTANT.';
		RAISE ERR_NN;
	END IF;

	-- comprovaci referncies: claus foranes
	SELECT COUNT (*) INTO existeix
	FROM EQUIP
     WHERE ID_EQUIP = paramEquip ;

	IF (existeix = 0) THEN
		MSG_EX := paramEquip || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

	SELECT COUNT (*) INTO existeix
	FROM REPRESENTANT_LEGAL
     WHERE ID_REPRESENTANT = paramRepresentant ;

	IF (existeix = 0) THEN
		MSG_EX := paramRepresentant || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;
	
-- INSERT del nou representant de lequip
INSERT INTO REP_EQUIP VALUES (paramEquip, paramDataIni, paramRepresentant, paramProtocol);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta REPRESENTANT_EQUIP realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Rep_Equip ;
/
