/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Federa
@Funcionalitat:		Afegir una fitxa de jugador federat a la BD.
@restriccions:		
@params IN:		paramFederacio NUMBER, 
				paramJugador NUMBER, 
				paramNumero NUMBER,
				paramAlta VARCHAR2(1),
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */    
create or replace PROCEDURE ins_Federa
(
  paramFederacio 	IN FEDERA.federacio%TYPE, 
  paramJugador		IN FEDERA.jugador%TYPE, 
  paramNumero 		IN FEDERA.numero%TYPE,
  paramAlta		IN FEDERA.alta%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;

BEGIN
RSP := 'KO';
procediment := 'ins_Federa'; 
paramEntrada := 'Federacio: ' || paramFederacio || 
          ' - Jugador: ' || paramJugador ||
          ' - Nmero: ' || paramNumero ||
          ' - Alta: ' || paramAlta;	

-- comprovar dades d'entrada:   
	IF (paramFederacio IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp FEDERACIO.';
		RAISE ERR_NN;
	ELSIF (paramJugador IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp JUGADOR.';
		RAISE ERR_NN;
	END IF;

	-- conprova si la federaci existeix
	SELECT COUNT (*) INTO existeix
	FROM FEDERACIO
     WHERE ID_FEDERACIO = paramFederacio ;

	IF (existeix = 0) THEN
		MSG_EX := 'La federaci ' || paramFederacio || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

	SELECT COUNT (*) INTO existeix
	FROM JUGADOR
     WHERE ID_JUGADOR = paramJugador ;

	IF (existeix = 0) THEN
		MSG_EX := 'El jugador ' || paramJugador || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;
	
-- INSERT d'una fitxa de jugador a una federaci
INSERT INTO FEDERA VALUES (paramFederacio, paramJugador, paramNumero, paramAlta);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta FITXA_FEDERAT realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
	 
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Federa ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Federa
@Funcionalitat:		Dona de baixa el jugador en la federaci, modificant el valor alta := 'N'
@restriccions		
@params IN			paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */   
create or replace PROCEDURE upd_Federa
(
  paramID		IN FEDERA.federacio%TYPE,
  paramNumero	IN FEDERA.numero%TYPE,
  
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_EX	EXCEPTION;
  ERR_NN	EXCEPTION;

   MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
     
BEGIN
  RSP := 'KO';
  procediment := 'upd_Federa'; 
  paramEntrada := 'ID_FEDERACIO' || paramID ||
				' Nmero federat: ' || paramNumero;
  
-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal emplenar el camp FEDERACIO.';
	RAISE ERR_NN;
  END IF;
  
  IF (paramNumero IS NULL) THEN
	MSG_NN := 'Cal emplenar el camp NUMERO FEDERAT.';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix la fitxa que es pretn donar de baixa:   
  SELECT count(*) INTO existeix 
  FROM FEDERA
  WHERE federacio = paramID AND numero = paramNumero;

  IF (existeix = 0) THEN
	MSG_EX := paramID || '' || paramNumero;
	RAISE ERR_EX;
  END IF;

-- actualitza l'estat    
  UPDATE FEDERA SET alta = 'N' WHERE federacio = paramID and numero = paramNumero;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades FITXA FEDERAT actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
	
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Federa ;
/
