/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				INS_CausaBaixa
@Funcionalitat:		Reflectir una baixa d'un jugador en un periode concret.
@params IN:		paramID NUMBER, 
				paramObs VARCHAR2(100),
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */     
create or replace PROCEDURE ins_CausaBaixa 
(
  paramID 		IN CAUSA_BAIXA.id_baixa%TYPE, 
  paramJugador	IN CAUSA_BAIXA.jugador%TYPE, 
  paramBaixa	IN CAUSA_BAIXA.dia_baixa%TYPE,
  paramAlta	IN CAUSA_BAIXA.dia_alta%TYPE,

  RSP 		OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);

BEGIN
RSP := 'KO';
procediment := 'ins_CausaBaixa'; 
paramEntrada := 'ID_BAIXA: ' || paramID || 
          ' - Jugador: ' || paramJugador ||
          ' - Dia baixa: ' || paramBaixa ||
          ' - Dia alta: ' || paramAlta ;	

-- comprovar dades d'entrada:   
	IF (paramID IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NMERO DE BAIXA';
		RAISE ERR_NN;
	END IF;

-- INSERT de la nova baixa
INSERT INTO CAUSA_BAIXA VALUES (paramID, paramJugador, paramBaixa, paramAlta);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta CAUSA_BAIXA realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
   
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_CausaBaixa ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_CausaBaixa
@Funcionalitat:		Modificar/actualitzar la data prevista d'incorporaci.
@restriccions		
@params IN:		paramID NUMBER;	
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */     
create or replace PROCEDURE upd_CausaBaixa
(
  paramID		IN CAUSA_BAIXA.id_baixa%TYPE,
  paramAlta 	IN CAUSA_BAIXA.dia_alta%TYPE,
    
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_EX	EXCEPTION;
  ERR_NN	EXCEPTION;
  
  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
 
  existeix INTEGER;
     
BEGIN
  RSP := 'KO';
  procediment := 'upd_CausaBaixa'; 
  paramEntrada := 'ID_BAIXA' || paramID ||
			' - Data alta: ' || paramAlta ;
  
-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal emplenar el camp NUMERO DE BAIXA.';
	RAISE ERR_NN;
  END IF;
  
-- comprovar si existeix la baixa que es vol donar d'alta o modificar la data prevista:   
  SELECT count(*) INTO existeix 
  FROM CAUSA_BAIXA
  WHERE id_baixa = paramID ;

  IF (existeix = 0) THEN
	MSG_EX := paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- actualitza escriu/reescriu la data d'alta:    
  UPDATE CAUSA_BAIXA SET dia_alta = paramAlta
  WHERE id_baixa = paramID ;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades CAUSA_BAIXA actualizades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_CausaBaixa ;
/