/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Competicio
@Funcionalitat:		Afegir una nova competicio a la BD.
@params IN:		paramNom VARCHAR2(20 CHAR), 
				paramAmbit VARCHAR2(11 CHAR),
				paramGenere VARCHAR2(1 CHAR),
				paramModalitat VARCHAR2(15 CHAR),
				paramCategoria VARCHAR2(7 CHAR),	
				paramFactor NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE ins_Competicio
(
  paramNom 		IN COMPETICIO.nom%TYPE, 
  paramAmbit		IN COMPETICIO.ambit%TYPE, 
  paramGenere		IN COMPETICIO.genere%TYPE,
  paramModalitat		IN COMPETICIO.modalitat%TYPE,
  paramCategoria		IN COMPETICIO.categoria%TYPE, 
  paramFactor	 	IN COMPETICIO.factor%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

BEGIN
RSP := 'KO';
procediment := 'ins_Competicio'; 
paramEntrada := 'Nom: ' || paramNom || 
          ' - Ambit: ' || paramAmbit||
          ' - Genere: ' || paramGenere || 
          ' - Modalitat: ' || paramModalitat || 
          ' - Categoria: ' || paramCategoria || 
          ' - Factor: ' || paramFactor;	

-- comprovar dades d'entrada:   
	IF (paramNom IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NOM.';
		RAISE ERR_NN;
	ELSIF (paramAmbit IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp AMBIT.';
		RAISE ERR_NN;
	ELSIF (paramGenere IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp GENERE("M","F")';
		RAISE ERR_NN;
	ELSIF (paramModalitat IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp MODALITAT("NORMAL","CADIRA DE RODES").';
		RAISE ERR_NN;
	ELSIF (paramCategoria IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp CATEGORIA("PRIMERA","SEGONA").';
		RAISE ERR_NN;
	ELSIF (paramFactor IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp FACTOR(p).';
		RAISE ERR_NN;
	END IF;

-- INSERT de la nova competicio
INSERT INTO COMPETICIO VALUES ('', paramNom, paramAmbit, paramGenere, paramModalitat, paramCategoria, paramFactor);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta COMPETICIO realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Competicio ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Competicio 
@Funcionalitat:		Eliminar un una competicio de la BD.
@restriccions		No es pot eliminar una competici de la que ja s'han jugat partits.
@params IN			paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE del_Competicio 
(
  paramID	IN COMPETICIO.id_competicio%TYPE,
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;
  
  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
  
  existeix INTEGER;
    
BEGIN
  RSP := 'KO';
  procediment := 'del_Competicio '; 
  paramEntrada := 'ID_COMPETICIO: ' || paramID;

-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de la COMPETICIO';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM COMPETICIO
  WHERE id_competicio = paramID;

  IF (existeix = 0) THEN
	MSG_EX := 'La competici ' || paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- comprova si hi ha partits que s'han jugat en aquesta competici:
  SELECT count(*) INTO existeix
  FROM PARTIT
  WHERE competicio = paramID
	AND dia_hora < sysdate;
	
  	IF (existeix > 0) THEN
		MSG_EX := 'Existeixen partits disputats en aquesta competici (' || paramID || ').';
		RAISE ERR_EX;
	END IF;

-- elimina la competici de la BD:    
  DELETE FROM COMPETICIO WHERE Competicio.id_competicio = paramID;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - COMPETICIO eliminada de la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Competicio  ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Competicio
@Funcionalitat:		Modificar el factor de ponderaci de la competici
@param:			
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE upd_Competicio 
(
  paramID	 		IN COMPETICIO.id_competicio%TYPE, 
  paramFactor		IN COMPETICIO.factor%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
  
BEGIN
RSP := 'KO';
procediment := 'upd_Competicio'; 
paramEntrada := 'Competicio: ' || paramID || 
          ' - Factor de ponderaci: ' || paramFactor ;	

-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de la competici.';
	RAISE ERR_NN;
  ELSIF (paramFactor IS NULL) THEN
	MSG_NN := 'Cal emplenar el camp FACTOR.';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM COMPETICIO
  WHERE id_competicio = paramID;

  IF (existeix = 0) THEN
	MSG_EX := 'La competici ' || paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- modificaci/actualitzaci del factor de ponderaci
UPDATE COMPETICIO SET factor = paramFactor 	WHERE id_competicio = paramID ;

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades COMPETICIO actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Competicio ;
/
