/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Nacional
@Funcionalitat:		Afegir una nova competicio nacional a la BD.
				Especialitzaci de l'entitat COMPETICIO
@params IN:		paramCompeticio NUMBER,
				paramPais NUMBER,
				paramTemporada VARCHAR2(9 CHAR),				
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE ins_Nacional
(
  paramCompeticio	IN NACIONAL.id_competicio%TYPE, 
  paramPais		IN NACIONAL.pais%TYPE, 
  paramTemporada		IN NACIONAL.temporada%TYPE, 
 
  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeixC NUMBER;
  existeixT NUMBER;
  existeixN NUMBER;

BEGIN
RSP := 'KO';
procediment := 'ins_Nacional'; 
paramEntrada := 'Competici: ' || paramCompeticio || 
          ' - Pais: ' || paramPais ||
          ' - Temporada: ' || paramTemporada ;	

-- comprovar dades d'entrada:   
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal indicar lidentificador de la COMPETICIO.';
		RAISE ERR_NN;
	END IF;
	IF (paramPais IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp PAIS.';
		RAISE ERR_NN;
	END IF;
	IF (paramTemporada IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp TEMPORADA.';
		RAISE ERR_NN;
	END IF;

-- comprovar si existeix la competici:
  SELECT count(*) INTO existeixC 
  FROM COMPETICIO
  WHERE id_competicio = paramCompeticio;

  	IF (existeixC = 0) THEN
  		MSG_EX := 'La competitio ' || paramCompeticio || ' no existeix a la BD.';
    	RAISE ERR_EX;
	  END IF;

-- comprovar si lidentificador ja est assignat
  SELECT count(*) INTO existeixC 
  FROM COMPETICIO WHERE id_competicio = (SELECT id_competicio from NACIONAL)
                    OR id_competicio = (SELECT id_competicio from INTERNACIONAL)
  AND id_competicio = paramCompeticio;

  	IF (existeixC = 1) THEN
  		MSG_EX := 'Lidenrificador ' || paramCompeticio || ' ja est assignat a una altra competici.';
    	RAISE ERR_EX;
	  END IF;
 
-- comprovar si existeix la temporada:
  SELECT count(*) INTO existeixT 
  FROM TEMPORADA
  WHERE id_temporada = paramTemporada;

  	IF (existeixT = 0) THEN
      MSG_EX := 'La temporada ' || paramTemporada || ' no existeix a la BD.';
      RAISE ERR_EX;
	  END IF;

-- comprovar si existeix la competici nacional:
  SELECT count(*) INTO existeixN 
  FROM NACIONAL
  WHERE id_competicio = paramCompeticio
    AND temporada = paramTemporada;

  	IF (existeixN = 1) THEN
      MSG_EX := 'La competicio ' || paramCompeticio || ' ' || paramTemporada || ' ja existeix a la BD.';
      RAISE ERR_EX;
	  END IF;

-- INSERT de la nova competicio nacional
INSERT INTO NACIONAL VALUES (paramCompeticio, paramPais, paramTemporada, '');

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta COMPETICIO NACIONAL realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Nacional ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Nacional 
@Funcionalitat:		Eliminar una competicio nacional de la BD.
@restriccions		No es pot eliminar una competici de la que ja s'han jugat partits.
@params IN			paramCompeticio NUMBER, 
				paramTemporada VARCHAR2(9),
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE del_Nacional 
(
  paramCompeticio	IN NACIONAL.id_competicio%TYPE,
  paramTemporada		IN NACIONAL.temporada%TYPE,

  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
    
BEGIN
  RSP := 'KO';
  procediment := 'del_Nacional'; 
  paramEntrada := 'ID_COMPETICIO' || paramCompeticio;

-- comprovar dades d'entrada:   
  IF (paramCompeticio IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de la COMPETICIO.';
	RAISE ERR_NN;
  END IF;

  IF (paramTemporada IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de la TEMPORADA.';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix la competici:
  SELECT count(*) INTO existeix 
  FROM COMPETICIO
  WHERE id_competicio = paramCompeticio;

  	IF (existeix = 0) THEN
		MSG_EX := 'La competitio ' || paramCompeticio || ' no existeix a la BD.';
		RAISE ERR_EX;
	  END IF;
 DBMS_OUTPUT.PUT_LINE('exCompeticio');
-- comprovar si existeix la temporada:
  SELECT count(*) INTO existeix 
  FROM TEMPORADA
  WHERE id_temporada = paramTemporada;

  	IF (existeix = 0) THEN
		MSG_EX := 'La temporada ' || paramTemporada || ' no existeix a la BD.';
		RAISE ERR_EX;
	  END IF;
 DBMS_OUTPUT.PUT_LINE('exTemporada');
-- comprovar si existeix la competici nacional:
  SELECT count(*) INTO existeix 
  FROM NACIONAL
  WHERE id_competicio = paramCompeticio
    AND temporada = paramTemporada;

  	IF (existeix = 0) THEN
		MSG_EX := 'La competicio ' || paramCompeticio || ' ' || paramTemporada || ' no existeix a la BD.';
		RAISE ERR_EX;
	  END IF;

-- comprova si hi ha partits jugats o programats.
  SELECT count(*) INTO existeix
  FROM PARTIT
  WHERE competicio = paramCompeticio;
	
  IF (existeix > 0) THEN
	MSG_EX := 'La competicio ' || paramCompeticio || ' ' || paramTemporada || ' t partits vinculats.';
	RAISE ERR_EX;
  END IF;
    
-- eliminar la competici nacional.
  DELETE FROM NACIONAL WHERE nacional.id_competicio = paramCompeticio AND temporada = paramTemporada;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades COMPETICIO_NACIONAL actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Nacional  ;
/
