/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Internacional
@Funcionalitat:		Afegir una nova competicio internacional a la BD.
				Especialitzaci de l'entitat COMPETICIO
@params IN:		paramCompeticio NUMBER,
				paramPais NUMBER,
				paramAny NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE ins_Internacional
(
  paramCompeticio	IN INTERNACIONAL.id_competicio%TYPE, 
  paramContinent	IN INTERNACIONAL.continent%TYPE, 
  paramAny			IN INTERNACIONAL.anyComp%TYPE,
 
  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix NUMBER;

BEGIN
RSP := 'KO';
procediment := 'ins_Internacional'; 
paramEntrada := 'Competici: ' || paramCompeticio || 
          ' - Continent: ' || paramContinent ||
          ' - Any: ' || paramAny ;	

-- comprovar dades d'entrada:   
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal indicar lidentificador de la COMPETICIO';
		RAISE ERR_NN;
	ELSIF (paramContinent IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp CONTINENT.';
		RAISE ERR_NN;
	ELSIF (paramAny IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp ANY (1950-2015).';
		RAISE ERR_NN;
	END IF;

-- comprovar si existeix la competici:
  SELECT count(*) INTO existeix 
  FROM COMPETICIO
  WHERE id_competicio = paramCompeticio;

  	IF (existeix = 0) THEN
		MSG_EX := 'La competicio ' || paramCompeticio || ' no existeix a la BD.';
		RAISE ERR_EX;
	  END IF;

-- comprovar si lidentificador ja est assignat
  SELECT count(*) INTO existeix 
  FROM COMPETICIO WHERE id_competicio = (SELECT id_competicio from NACIONAL)
                    OR id_competicio = (SELECT id_competicio from INTERNACIONAL)
  AND id_competicio = paramCompeticio;

  	IF (existeix = 1) THEN
  		MSG_EX := 'Lidenrificador ' || paramCompeticio || ' ja est assignat a una altra competici.';
    	RAISE ERR_EX;
	  END IF;

-- comprovar si existeix la competici internacional:
  SELECT count(*) INTO existeix 
  FROM INTERNACIONAL
  WHERE id_competicio = paramCompeticio
	AND anyComp = paramAny;

  	IF (existeix = 1) THEN
		MSG_EX := 'La competicio ' || paramCompeticio || ' ' || paramAny || ' ja existeix a la BD.';
		RAISE ERR_EX;
	  END IF;

-- INSERT de la nova competicio internacional
INSERT INTO INTERNACIONAL VALUES (paramCompeticio, paramContinent, paramAny, '');

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta COMPETICIO INTERNACIONAL realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Internacional ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Internacional
@Funcionalitat:		Eliminar una competicio internacional de la BD.
@restriccions		No es pot eliminar una competici de la que ja s'han jugat partits
@params IN			paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE del_Internacional 
(
  paramCompeticio	IN INTERNACIONAL.id_competicio%TYPE,
  paramAny			IN INTERNACIONAL.anyComp%TYPE,

  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
    
BEGIN
  RSP := 'KO';
  procediment := 'del_Internacional'; 
  paramEntrada := 'ID_COMPETICIO' || paramCompeticio ||
	        ' - Any: ' || paramAny ;

-- comprovar dades d'entrada:   
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal indicar lidentificador de la COMPETICIO';
		RAISE ERR_NN;
	END IF;

	IF (paramAny IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp ANY (1950-2015).';
		RAISE ERR_NN;
	END IF;

-- comprovar si existeix la competici:
  SELECT count(*) INTO existeix 
  FROM COMPETICIO
  WHERE id_competicio = paramCompeticio;

  	IF (existeix = 0) THEN
		MSG_EX := 'La competicio ' || paramCompeticio || ' no existeix a la BD.';
		RAISE ERR_EX;
	  END IF;

-- comprovar si existeix la competici internacional:
  SELECT count(*) INTO existeix 
  FROM INTERNACIONAL
  WHERE id_competicio = paramCompeticio
	AND anyComp = paramAny;

  	IF (existeix = 0) THEN
		MSG_EX := 'La competicio ' || paramCompeticio || ' ' || paramAny || ' ja existeix a la BD.';
		RAISE ERR_EX;
	  END IF;

-- comprova si hi ha partits jugats o programats:
  SELECT count(*) INTO existeix
  FROM PARTIT
  WHERE competicio = paramCompeticio;
	
  IF (existeix > 0) THEN
	MSG_EX := 'La competicio ' || paramCompeticio || ' ' || paramAny || ' t partits vinculats.';
	RAISE ERR_EX;
  END IF;

-- elimina la competici internacional:    
  DELETE FROM INTERNACIONAL WHERE id_competicio = paramCompeticio AND anyComp = paramAny;

  --UPDATE EST_81 set jugadors = jugadors -1
 -- WHERE genere = oldGenere AND modalitat = oldModalitat ;  
-- resultat actualitzaci EST_81: CORRECTA

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades COMPETICIO_INTERNACIONAL actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Internacional ;
/
