/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Arbitre
@Funcionalitat:		Afegir un nou arbitre a la BD
@params IN:		paramNom VARCHAR2(20 CHAR), 
				paramCognom1 VARCHAR2(20 CHAR),
				paramCognom2 VARCHAR2(20 CHAR),
				paramTelefon VARCHAR2(20 CHAR),		
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE ins_Arbitre 
(
  paramNom 		    IN ARBITRE.nom%TYPE, 
  paramCognom1		IN ARBITRE.cognom1%TYPE, 
  paramCognom2		IN ARBITRE.cognom2%TYPE, 
  paramTelefon 		IN ARBITRE.telefon%TYPE,
  
  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);

BEGIN
RSP := 'KO';
procediment := 'ins_Arbitre'; 
paramEntrada := 'Nom: ' || paramNom || 
          ' - Cognom1: ' || paramCognom1 ||
          ' - Cognom2: ' || paramCognom2 ||
          ' - Telefon: ' || paramTelefon;	

-- comprovar dades d'entrada:   
	IF (paramNom IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NOM.';
		RAISE ERR_NN;
	ELSIF (paramCognom1 IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp Cognom1.';
		RAISE ERR_NN;
	END IF;

-- INSERT d'un nou rbitre:
INSERT INTO ARBITRE VALUES ('', paramNom, paramCognom1, paramCognom2, paramTelefon);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta ARBITRE realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Arbitre ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Arbitre
@Funcionalitat:		Eliminar un arbitre de la BD.
@restriccions		No es pot eliminar si ha arbitrat, al menys, un partit.
@params IN			paramID NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE del_Arbitre 
(
  paramID	IN ARBITRE.id_arbitre%TYPE,
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;
 
  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
  
  existeix INTEGER;
    
BEGIN
  RSP := 'KO';
  procediment := 'del_Arbitre'; 
  paramEntrada := 'ID_ARBITRE' || paramID;

-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de lrbitre.';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM ARBITRE
  WHERE id_arbitre = paramID;

  IF (existeix = 0) THEN
	MSG_EX := 'Lrbitre ' || paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- comprova si ha arbitrat cap partit:
  SELECT count(*) INTO existeix
  FROM EQUIP_ARBITRAL
  WHERE arbitre = paramID;
	
  IF (existeix > 0) THEN
	MSG_EX := 'Lrbitre ' || paramID || ' ja ha participat en partits.';
	RAISE ERR_EX;
  END IF;

-- elimina l'arbitre de la BD:
  DELETE FROM ARBITRE  WHERE id_arbitre = paramID;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - ARBITRE eliminat de la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Arbitre ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Arbitre
@Funcionalitat:		Modificar el telfon o el titol de l'rbitre.
@param:			
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE upd_Arbitre 
(
  paramID		IN ARBITRE.id_arbitre%TYPE,
  paramTelefon	IN ARBITRE.telefon%TYPE,
    
  RSP 	OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix 	INTEGER;
  inici		DATE;
  
BEGIN
  RSP := 'KO';
  procediment := 'upd_Arbitre'; 
  paramEntrada := 'ID_ARBITRE' || paramID ||
				' - Telefon: ' || paramTelefon ;
				
-- comprovar dades d'entrada:   
  IF (paramID IS NULL) THEN
	MSG_NN := 'Cal indicar lidentificador de lrbitre.';
	RAISE ERR_NN;
  END IF;

-- comprovar si existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM ARBITRE
  WHERE id_arbitre = paramID;

  IF (existeix = 0) THEN
	MSG_EX := 'Lrbitre ' || paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- Introduir o modificar el telfon de lrbitre:
  IF (paramTelefon IS NOT NULL) THEN
	UPDATE ARBITRE SET telefon = paramTelefon
	WHERE id_arbitre = paramID;
  END IF;
	
RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades ARBITRE actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Arbitre ;
/
