/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Equip_Arbitral
@Funcionalitat:		Afegir un nou arbitre al equip que arbitra un partit: 2, si s una competici nacional; 3, si la competici s internacional.
@params IN:		paramPartit NUMBER, 
				paramArbitre NUMBER,
				paramCompeticio NUMBER,
				paramRol VARCHAR2(20 CHAR),
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE ins_Equip_Arbitral 
(
  paramPartit 		IN EQUIP_ARBITRAL.partit%TYPE,
  paramArbitre		IN EQUIP_ARBITRAL.arbitre%TYPE,
  paramCompeticio	IN EQUIP_ARBITRAL.competicio%TYPE,
  paramRol			IN EQUIP_ARBITRAL.rol%TYPE,

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_EX	EXCEPTION;
  ERR_NN	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix	NUMBER;
  arbitres	NUMBER;
  tipus	VARCHAR2(3);

BEGIN
RSP := 'KO';
procediment := 'ins_Equip_Arbitral';
paramEntrada := 'Partit: ' || paramPartit ||
          ' - Arbitre: ' || paramArbitre ||
          ' - Competicio: ' || paramCompeticio ||
          ' - Rol: ' || paramRol;

-- comprovar dades d'entrada:
	IF (paramPartit IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp PARTIT.';
		RAISE ERR_NN;
    ELSE
      -- comprovar si el partit existeix en la BD:
      SELECT count(*) INTO existeix
      FROM PARTIT
      WHERE id_partit = paramPartit;

      IF (existeix = 0) THEN
      MSG_EX := 'El partit ' || paramPartit || ' no existeix a la BD.';
      RAISE ERR_EX;
      END IF;
	END IF;
	
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp COMPETICIO.';
		RAISE ERR_NN;
    ELSE
      -- comprovar si la competicio existeix en la BD:
      SELECT count(*) INTO existeix
      FROM COMPETICIO
      WHERE id_competicio = paramCompeticio;

      IF (existeix = 0) THEN
        MSG_EX := 'La competicio ' || paramCompeticio || ' no existeix a la BD.';
        RAISE ERR_EX;
      END IF;
      -- competici nacional o internacional?
      SELECT count(*) INTO existeix
      FROM NACIONAL
      WHERE id_competicio = paramCompeticio ;
    
      IF (existeix = 1) THEN
        tipus := 'NAC';
      ELSIF (existeix = 0) THEN
        tipus := 'INT';
      END IF;
      
      -- el partit correspon a aquesta competici?
      SELECT COUNT(*) INTO existeix
      FROM PARTIT
      WHERE id_partit = paramPartit AND competicio = paramCompeticio;
      
      IF (existeix = 0) THEN
        MSG_EX := 'El partit no forma part daquesta competici!';
        RAISE ERR_EX;
      END IF;
	END IF;
  
  IF (paramArbitre IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp ARBITRE.';
		RAISE ERR_NN;
    ELSE
      -- comprovar si lrbitre existeix en la BD:
      SELECT count(*) INTO existeix
      FROM ARBITRE
      WHERE id_arbitre = paramArbitre;

      IF (existeix = 0) THEN
        MSG_EX := 'Lidentificador ' || paramArbitre || ' no existeix a la BD.';
        RAISE ERR_EX;
      END IF;
	END IF;
  
	IF (paramRol IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp ROL.';
		RAISE ERR_NN;
      -- comprovar si el rol est assignat
      SELECT count(*) into existeix
      FROM EQUIP_ARBITRAL
      WHERE partit = paramPartit
      AND rol = paramRol;

      IF (existeix > 0) THEN
        MSG_EX := 'El rol ' || paramRol || ' ja est cobert per un altre rbitre.';
        RAISE ERR_EX;
      END IF;
	END IF;

-- comprovar el nmero d'rbitres assignat aL PARTIT:
	SELECT count(*) into arbitres
	FROM EQUIP_ARBITRAL
	WHERE partit = paramPartit ;

-- INSERT d'un nou arbitre al partit d'una competici:
  IF ((arbitres < 3 AND tipus = 'NAC') OR (arbitres < 4 AND tipus = 'INT')) THEN
	INSERT INTO EQUIP_ARBITRAL VALUES (paramPartit, paramArbitre, paramCompeticio, paramRol);
	ELSE
		MSG_EX := 'El nmero drbitres excedeix el mxim perms';
		RAISE ERR_EX;
  END IF;

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta EQUIP_ARBITRAL realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Equip_Arbitral ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Equip_Arbitral
@Funcionalitat:		Eliminar un arbitre de l'equip definit inicalment.
@restriccions		No es pot eliminar si el partit ja ha comenat
@params IN			paramID NUMBER, 
				paramArbitre NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE del_Equip_Arbitral 
(
  paramPartit	IN EQUIP_ARBITRAL.partit%TYPE,
  paramArbitre	IN EQUIP_ARBITRAL.arbitre%TYPE,
  
  RSP 			OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
  
BEGIN
  RSP := 'KO';
  procediment := 'del_Equip_Arbitral'; 
  paramEntrada := 'ID_PARTIT: ' || paramPartit ||
			' - ID_ARBITRE: ' || paramArbitre;

-- comprovar dades d'entrada:   
	IF (paramPartit IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp PARTIT.';
		RAISE ERR_NN;
	END IF;
	IF (paramArbitre IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp ARBITRE.';
		RAISE ERR_NN;
	END IF;

-- comprovar si el partit existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM PARTIT
  WHERE id_partit = paramPartit;

  IF (existeix = 0) THEN
	MSG_EX := 'El partit ' || paramPartit || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- comprovar si lrbitre existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM ARBITRE
  WHERE id_arbitre = paramArbitre;

  IF (existeix = 0) THEN
	MSG_EX := 'El partit ' || paramArbitre || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- comprova si forma part de lequip arbitral:
  SELECT count(*) INTO existeix 
  FROM EQUIP_ARBITRAL
  WHERE partit = paramPartit
	AND arbitre = paramArbitre;

  IF (existeix = 0) THEN
	MSG_EX := 'Lrbitre ' || paramArbitre || ' no forma part daquest equip arbitral.';
	RAISE ERR_EX;
  END IF;

-- elimina l'arbitre de lequip arbitral:
DELETE FROM EQUIP_ARBITRAL WHERE arbitre = paramArbitre AND partit = paramPartit;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - EQUIP_ARBITRAL eliminat de la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Equip_Arbitral ;
/