/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Club
@Funcionalitat:		Afegir un nou club.
				Entitat especialitzaci dEQUIP.
@params IN:		paramID NUMBER, 
				paramSocis NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE ins_Club 
(
  paramID 		IN CLUB.id_equip%TYPE, 
  paramSocis	IN CLUB.socis%TYPE, 
  paramDia    IN CLUB.dia%TYPE,
  
  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix NUMBER;

BEGIN
RSP := 'KO';
procediment := 'ins_Club'; 
paramEntrada := 'ID_EQUIP: ' || paramID ||
		' - Nmero de socis: ' || paramSocis ||
    ' - Data: ' || paramDia;	

-- comprovar dades dentrada:   
	IF (paramID IS NULL) THEN
		MSG_NN := 'Cal indicar lidentificador del CLUB.';
		RAISE ERR_NN;
	END IF;
	IF (paramSocis IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NMERO DE SOCIS.';
		RAISE ERR_NN;	
	END IF;
  IF (paramDia IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp DIA.';
		RAISE ERR_NN;	
	END IF;

-- comprovar si el partit existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM EQUIP
  WHERE id_equip = paramID;

  IF (existeix = 0) THEN
	MSG_EX := 'Lequip ' || paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- INSERT del nmero de socis d'un club
INSERT INTO CLUB VALUES (paramID, paramSocis, paramDia);

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta CLUB realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Club ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_club
@Funcionalitat:		Modificar el nmero de socis d'un club
@param:			paramID NUMBER,
				paramSocis NUMBER,
				paramDia DATE,
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE upd_Club 
(
  paramID 		IN CLUB.id_equip%TYPE, 
  paramSocis	IN CLUB.socis%TYPE, 
  paramDia		IN CLUB.dia%TYPE, 
  
  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix NUMBER;

BEGIN
RSP := 'KO';
procediment := 'upd_Club'; 
paramEntrada := 'ID_EQUIP: ' || paramID ||
		' - Nmero de socis: ' || paramSocis ;	

-- comprovar dades d'entrada:   
	IF (paramID IS NULL) THEN
		MSG_NN := 'Cal indicar lidentificador del CLUB.';
		RAISE ERR_NN;
	END IF;
	IF (paramSocis IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NMERO DE SOCIS.';
		RAISE ERR_NN;	
	END IF;
	IF (paramDia IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp DATA.';
		RAISE ERR_NN;	
	END IF;

-- comprovar si el partit existeix en la BD:   
  SELECT count(*) INTO existeix 
  FROM EQUIP
  WHERE id_equip = paramID;

  IF (existeix = 0) THEN
	MSG_EX := 'Lequip ' || paramID || ' no existeix a la BD.';
	RAISE ERR_EX;
  END IF;

-- modifica el nmero de socis d'un club
UPDATE CLUB SET socis = paramSocis, dia = paramDia
WHERE id_equip = paramID;

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades COMPETICIO actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Club ;
/