/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Classificacio
@Funcionalitat:		Afegir un nou registre de participaci d'un equip en una competicio i temporada.
				Si ja existeix, incrementa els punts segons el valor del parmetre d'entrada.
@params IN:		paramCompeticio NUMBER, 
				paramEquip NUMBER,	
				paramPunts NUMBER,				
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE ins_Classificacio
(
  paramCompeticio	IN CLASSIFICACIO.competicio%TYPE, 
  paramEquip		IN CLASSIFICACIO.equip%TYPE, 
  paramPunts		IN CLASSIFICACIO.punts%TYPE, 

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
  
  existeixN NUMBER;
  existeixE NUMBER;
  existeixC NUMBER;
  varPunts NUMBER;

BEGIN
RSP := 'KO';
procediment := 'ins_Classificacio'; 
paramEntrada := 'Competicio: ' || paramCompeticio || 
          ' - Equip: ' || paramEquip ||
          ' - punts: ' || paramPunts ;	

-- comprovar dades d'entrada:   
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp COMPETICIO.';
		RAISE ERR_NN;
	END IF;

	IF (paramEquip IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp EQUIP.';
		RAISE ERR_NN;
	END IF;

-- comprovar si la competicio existeix:
	SELECT count(*) into existeixN
	FROM NACIONAL
	WHERE id_competicio = paramCompeticio ;
		
	IF (existeixN = 0) THEN
		MSG_EX := 'La competici ' || paramCompeticio || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

-- comprovar si lequip existeix:
	SELECT count(*) into existeixE
	FROM EQUIP
	WHERE id_equip = paramEquip ;

	IF (existeixE = 0) THEN
		MSG_EX := 'Lequip ' || paramEquip || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

-- comprovar si existeix el registre:
	SELECT count(*) into existeixC
	FROM CLASSIFICACIO
	WHERE competicio = paramCompeticio
		AND equip = paramEquip;

	IF (existeixC = 1) THEN
    SELECT punts INTO varPunts
    FROM CLASSIFICACIO
    WHERE competicio = paramCompeticio AND equip = paramEquip;

    UPDATE CLASSIFICACIO set punts = varPunts + paramPunts
    WHERE competicio = paramCompeticio AND equip = paramEquip;
    -- INSERT d'un nou equip a la competici:
    ELSIF (existeixC = 0) THEN
    DBMS_OUTPUT.PUT_LINE('insert');
      INSERT INTO CLASSIFICACIO VALUES (paramCompeticio, paramEquip, paramPunts);  
	END IF;

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta CLASSIFICACIO realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Classificacio ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Classificacio
@Funcionalitat:		Modificar els punts d'un equip en una competici.
@param:			paramCompeticio NUMBER,
				paramEquip NUMBER,				
				paramPunts NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE upd_Classificacio 
(
  paramCompeticio	IN CLASSIFICACIO.competicio%TYPE, 
  paramEquip		IN CLASSIFICACIO.equip%TYPE, 
  paramPunts		IN CLASSIFICACIO.punts%TYPE,

  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
  
BEGIN
RSP := 'KO';
procediment := 'upd_Classificacio'; 
paramEntrada := 'Competicio: ' || paramCompeticio || 
		' - Equip:	' ||	paramEquip ||        
		' - Punts: ' || paramPunts ;	

-- comprovar dades d'entrada:   
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp COMPETICIO.';
		RAISE ERR_NN;
	END IF;
	IF (paramEquip IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp EQUIP.';
		RAISE ERR_NN;
	END IF;
	IF (paramPunts IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp PUNTS.';
		RAISE ERR_NN;
	END IF;

-- comprovar si la competicio existeix:
	SELECT count(*) into existeix
	FROM COMPETICIO
	WHERE id_competicio = paramCompeticio ;
				
	IF (existeix > 0) THEN
		MSG_EX := 'La competici ' || paramCompeticio || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

-- comprovar si lequip existeix:
	SELECT count(*) into existeix
	FROM EQUIP
	WHERE id_equip = paramEquip ;
				
	IF (existeix > 0) THEN
		MSG_EX := 'Lequip ' || paramEquip || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;
	
-- comprovar si existeix el registre:
	SELECT count(*) into existeix
	FROM CLASSIFICACIO
	WHERE competicio = paramCompeticio
		AND equip = paramEquip;

	IF (existeix = 0) THEN
		MSG_EX := 'Cal inicialitzar aquesta entrada.';
		RAISE ERR_EX;
	END IF;
		
-- Modificaci dels punts de lequip en la competici:
	UPDATE CLASSIFICACIO SET punts = punts + paramPunts
	WHERE competicio = paramCompeticio
		AND equip = paramEquip;

RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades CLASSIFICACIO actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Classificacio ;
/