/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				ins_Participa
@Funcionalitat:		Introduir les dades d'un jugador en un partit.
				Permet inicialitzar les dades del partit a zero per modificar-les en el transcurs del partit a mida ue es produeixen.
@params IN:		paramPartit NUMBER, 
				paramJugador NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE ins_Participa 
(
  paramPartit 		IN PARTICIPA.partit%TYPE, 
  paramJugador 		IN PARTICIPA.jugador%TYPE, 
   
  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(128);
  MSG_NN 	VARCHAR2(64);
  MSG_EX 	VARCHAR2(64);
  
  existeix	NUMBER;
  eq1		NUMBER;
  eq2		NUMBER;
  dia		DATE;
  varEquip  NUMBER;
  varJugadors NUMBER;
  
BEGIN
RSP := 'KO';
procediment := 'ins_Participa'; 
paramEntrada := 'Partit: ' || paramPartit || 
          ' - Jugador: ' || paramJugador ;

-- comprovar dades d'entrada:   
	IF (paramPartit IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp PARTIT.';
		RAISE ERR_NN;
    ELSE
      SELECT COUNT(*) INTO existeix
      FROM PARTIT
      WHERE id_partit = paramPartit;
      
      IF (existeix = 0) THEN
      MSG_EX := 'Lidentificador del partit no existeix a la BD.';
      RAISE ERR_EX;
      END IF;
	END IF;
	IF (paramJugador IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp JUGADOR.';
		RAISE ERR_NN;
     ELSE
      SELECT COUNT(*) INTO existeix
      FROM JUGADOR
      WHERE id_jugador = paramJugador;
      
      IF (existeix = 0) THEN
      MSG_EX := 'Lidentificador del jugador no existeix a la BD.';
      RAISE ERR_EX;
      END IF;
	END IF;

	SELECT dia_hora INTO dia
	FROM PARTIT
	WHERE id_partit = paramPartit;

-- comprovar si el registre est inicialitzat
	SELECT count(*) into existeix
	FROM PARTICIPA
	WHERE partit = paramPartit 
		AND jugador = paramJugador;
		  		  		
	IF (existeix = 1) THEN
		MSG_EX := 'Ja existeix un registre per a aquest jugador i partit';
		RAISE ERR_EX;
	END IF;
		
  -- comprovar si el jugador pertany a un dels equips participants (local o visitant).
    SELECT dia_hora, eqLocal, eqVisitant INTO dia, eq1, eq2
    FROM PARTIT
      WHERE id_partit = paramPartit;
      
 SELECT count(*) INTO existeix
 FROM CONTRACTE
 WHERE jugador = paramJugador 
  AND (equipC = eq1 OR equipC = eq2)
  AND dia BETWEEN data_inici AND data_fi;

  IF (existeix = 0) THEN
    MSG_EX := 'El jugador ' || paramJugador || ' no t contracte vigent amb aquests equips.';   		
    RAISE ERR_EX;  
  END IF;

  -- control nmero de jugadors per equip
  SELECT equipC INTO varEquip
  FROM CONTRACTE
  WHERE jugador = paramJugador;
  
  SELECT COUNT(*) INTO varJugadors
  FROM PARTICIPA p INNER JOIN PARTIT t ON p.partit = t.id_partit
    INNER JOIN CONTRACTE c ON c.jugador = p.jugador AND (c.equipC = t.eqLocal OR c.equipC = t.eqvisitant)
    WHERE p.partit = paramPartit and c.equipC = varEquip;
  
  IF (varJugadors = 12) THEN
    MSG_EX := 'Excedeix el nmero de jugadors per equip';
    RAISE ERR_EX;
  END IF;  
  
INSERT INTO PARTICIPA VALUES (paramPartit, paramJugador,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0); 
		 	  
RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta PARTICIPA realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Participa ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				del_Participa
@Funcionalitat:		Eliminar un jugador de lequip participant.
@restriccions		El partit no pot haver comenat: estat = 'P'.
@params IN:		paramPartit NUMBER, 
				paramJugador NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE del_Participa 
(
  paramPartit	IN PARTICIPA.partit%TYPE,
  paramJugador	IN PARTICIPA.jugador%TYPE,
  
  RSP 		OUT NOCOPY VARCHAR2
)
AS
 
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(15);
  text		VARCHAR2(512);

  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;
 
   MSG_ERR	VARCHAR2(128);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);

  existeix INTEGER;
  est   VARCHAR2(1);
      
BEGIN
  RSP := 'KO';
  procediment := 'del_Participa'; 
  paramEntrada := 'ID_PARTIT: ' || paramPartit ||
				' - ID_JUGADOR: ' || paramJugador;

-- comprovar dades d'entrada:   
	IF (paramPartit IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp PARTIT.';
		RAISE ERR_NN;
	END IF;
	IF (paramJugador IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp JUGADOR.';
		RAISE ERR_NN;
	END IF;
		  		  
-- comprovar si el registre est inicialitzat
	SELECT count(*) INTO existeix
	FROM PARTICIPA
	WHERE partit = paramPartit 
		AND jugador = paramJugador;
		
	IF (existeix = 0) THEN
		MSG_EX := 'Cal inicialitzar el registre per a aquest jugador i partit';
		RAISE ERR_EX;
	END IF;

-- comprova l'estat de l'equip:
	SELECT estat INTO est
	FROM PARTIT
	WHERE id_partit = paramPartit;
		
	IF (est != 'P') THEN
		MSG_EX := 'El partit ja ha comenat i/o finalitzat.';
		RAISE ERR_EX;
	END IF;

-- elimina la participaci del jugador en el partit:	
DELETE FROM PARTICIPA WHERE partit = paramPartit AND jugador = paramJugador;

RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - PARTICIPA eliminat de la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END del_Participa ;
/
/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:				upd_Participa
@Funcionalitat:		Modificar qualsevol de les dades d'un jugador en un partit.
@params IN:		paramPartit NUMBER, 
				paramJugador NUMBER, 
				paramMinuts NUMBER, 
				paramPT NUMBER, 
				paramT1E NUMBER, 
				paramT1I NUMBER, 
				paramT2E NUMBER, 
				paramT2I NUMBER,
				paramT3E NUMBER, 
				paramT3I NUMBER, 
				paramRD NUMBER, 
				paramRO NUMBER, 
				paramASS NUMBER, 
				paramTF NUMBER, 
				paramTC NUMBER, 
				paramPR NUMBER, 
				paramPP NUMBER, 
				paramFR NUMBER, 
				paramFC NUMBER, 
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */
create or replace PROCEDURE upd_Participa 
(
  paramPartit 		IN PARTICIPA.partit%TYPE, 
  paramJugador 		IN PARTICIPA.jugador%TYPE, 
  paramMinuts		IN PARTICIPA.minuts%TYPE, 
  paramPT			IN PARTICIPA.pt%TYPE, 
  paramT1E			IN PARTICIPA.t1e%TYPE,
  paramT1I			IN PARTICIPA.t1i%TYPE,
  paramT2E			IN PARTICIPA.t2e%TYPE,
  paramT2I			IN PARTICIPA.t2i%TYPE,
  paramT3E			IN PARTICIPA.t3e%TYPE,
  paramT3I			IN PARTICIPA.t3i%TYPE,
  paramRD			IN PARTICIPA.rd%TYPE,
  paramRO			IN PARTICIPA.ro%TYPE,
  paramASS			IN PARTICIPA.ass%TYPE,
  paramTF			IN PARTICIPA.tf%TYPE,
  paramTC			IN PARTICIPA.tc%TYPE,
  paramPR			IN PARTICIPA.pr%TYPE,
  paramPP			IN PARTICIPA.pp%TYPE,
  paramFR			IN PARTICIPA.fr%TYPE,
  paramFC			IN PARTICIPA.fc%TYPE,
  
  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;
 
  MSG_ERR	VARCHAR2(128);
  MSG_NN 	VARCHAR2(64);
  MSG_EX 	VARCHAR2(64);
   
  existeix	NUMBER;
  VA 		NUMBER := 0;
  fp		NUMBER;
  varComp	NUMBER;
  varTemp	VARCHAR2(9);
  varGenere VARCHAR2(1); 
  varModalitat VARCHAR2(15);

BEGIN
RSP := 'KO';
procediment := 'upd_Participa'; 
paramEntrada := 'Partit: ' || paramPartit || 
          ' - Jugador: ' || paramJugador ||
          ' - Minuts: ' || paramMinuts ||
          ' - Punts: ' || paramPT ||
          ' - T1E: ' || paramT1E ||
          ' - T1I: ' || paramT1I ||
          ' - T2E: ' || paramT2E ||
          ' - T2I: ' || paramT2I ||
          ' - T3E: ' || paramT3E ||
          ' - T3I: ' || paramT3I ||
          ' - RD: ' || paramRD ||
          ' - RO: ' || paramRO ||
          ' - ASS: ' || paramASS ||
          ' - TF: ' || paramTF ||
          ' - TC: ' || paramTC ||
          ' - PR: ' || paramPR ||
          ' - PP: ' || paramPP ||
          ' - FR: ' || paramFR ||
          ' - FC: ' || paramFC ;

-- comprovar dades d'entrada:   
	IF (paramPartit IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp PARTIT.';
		RAISE ERR_NN;
	END IF;
	IF (paramJugador IS NULL) THEN	
		MSG_NN := 'Cal emplenar el camp JUGADOR.';
		RAISE ERR_NN;
	END IF;
  	  		  
-- comprovar si el registre est inicialitzat
	SELECT count(*) into existeix
	FROM PARTICIPA
	WHERE partit = paramPartit 
		AND jugador = paramJugador;
		  		  		
	IF (existeix = 0) THEN
		MSG_EX := 'No existeix un registre per a aquest jugador i partit';
		RAISE ERR_EX;
	END IF;
 
-- quin s el factor de ponderaci per a aquest partit? Cerquem, a ms, dades per a tractament estadstic:
	SELECT c.id_competicio, c.factor, c.modalitat, c.genere, n.temporada  INTO varComp, fp, varModalitat, varGenere, varTemp
	FROM COMPETICIO c INNER JOIN PARTIT p ON c.id_competicio = p.competicio
    INNER JOIN NACIONAL n ON c.id_competicio = n.id_competicio
    WHERE p.id_partit = paramPartit ;

-- Es poden introduir les dades a mesura que es van produnt:
	IF (paramMinuts > 0) THEN
		UPDATE PARTICIPA SET minuts = minuts + paramMinuts
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;	
	IF (paramPT > 0) THEN
    VA := VA + paramPT;
		UPDATE PARTICIPA SET PT = PT + paramPT
    WHERE partit = paramPartit AND jugador = paramJugador;	
	END IF;
	IF (paramT1E IS NOT NULL) THEN
    VA := VA + paramT1E;
		UPDATE PARTICIPA SET T1E = T1E + paramT1E
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramT1I IS NOT NULL) THEN
    VA := VA - paramT1I;
		UPDATE PARTICIPA SET T1I = T1I + paramT1I
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramT2E IS NOT NULL) THEN
    VA := VA + paramT2E;
		UPDATE PARTICIPA SET T2E = T2E + paramT2E
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramT2I IS NOT NULL) THEN
    VA := VA - paramT2I;
		UPDATE PARTICIPA SET T2I = T2I + paramT2I
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramT3E IS NOT NULL) THEN
    VA := VA + paramT3E;
		UPDATE PARTICIPA SET T3E = T3E + paramT3E
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramT3I IS NOT NULL) THEN
    VA := VA - paramT3I;
		UPDATE PARTICIPA SET T3I = T3I + paramT3I
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramRD IS NOT NULL) THEN
    VA := VA + paramRD;
		UPDATE PARTICIPA SET RD = RD + paramRD
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramRO IS NOT NULL) THEN
    VA := VA + paramRO;
		UPDATE PARTICIPA SET RO = RO + paramRO
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramASS IS NOT NULL) THEN
    VA := VA + paramASS;
		UPDATE PARTICIPA SET ASS = ASS + paramASS
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramTF IS NOT NULL) THEN
    VA := VA + paramTF;
		UPDATE PARTICIPA SET TF = TF + paramTF
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramTC IS NOT NULL) THEN
    VA := VA - paramTC;
		UPDATE PARTICIPA SET TC = TC + paramTC
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramPR IS NOT NULL) THEN
    VA := VA + paramPR;
		UPDATE PARTICIPA SET PR = PR + paramPR
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;		
	IF (paramPP IS NOT NULL) THEN
    VA := VA - paramPP;
		UPDATE PARTICIPA SET PP = PP + paramPP
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;
	IF (paramFR IS NOT NULL) THEN
    VA := VA + paramFR; 
		UPDATE PARTICIPA SET FR = FR + paramFR
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;
	IF (paramFC IS NOT NULL) THEN
    VA := VA + paramFC; 
		UPDATE PARTICIPA SET FC = FC + paramFC
    WHERE partit = paramPartit AND jugador = paramJugador;
	END IF;
	-- actualitza el valor i el valor ponderat:
	UPDATE PARTICIPA SET V = V + VA, VP =  (V + VA) * fp
  WHERE partit = paramPartit AND jugador = paramJugador;

DBMS_OUTPUT.PUT_LINE('text3: '  || ' - ' ||  varComp  || ' - ' || varModalitat || ' - ' || varGenere || ' - ' || varTemp || ' - fp: ' || fp);  

COMMIT;
-- actualitza el mxim anotador:
  act_EST_82(varComp, RSP);
-- actualitza els millors equips ofensiu i defensiu:
  act_EST_86(varComp, varTemp, RSP);
-- actualitza el millor jugador del mn -gnere i modalitat- en base aa la mitjana de vp ms alta:
  act_EST_87(varGenere, varModalitat, RSP);
  
RSP := 'OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Dades PARTICIPACIO actualitzades a la BD.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END upd_Participa ;
/