/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:			ins_Canvi
@Funcionalitat:	Afegir un nou jugador
@params IN:	paramDivisa VARCHAR2(3 CHAR), 
			paramDia DATE,
			paramCanvi NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE ins_Canvi
(
  paramDivisa 		IN CANVI.divisa%TYPE, 
  paramDia		IN CANVI.dia%TYPE, 
  paramCanvi	IN CANVI.canvi%TYPE,

  RSP 		OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(96);
  MSG_NN 	VARCHAR2(96);
  MSG_EX 	VARCHAR2(96);
  
  existeix	NUMBER;

BEGIN
RSP := 'KO';
procediment := 'ins_Canvi'; 
paramEntrada := 'Divisa: ' || paramDivisa || 
          ' - Dia: ' || paramDia || 
          ' - Canvi: ' || paramCanvi;	

-- comprova dades d'entrada:   
	IF (paramDivisa IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp DIVISA.';
		RAISE ERR_NN;
	END IF;

-- comprova si existeix:
	SELECT count(*) INTO existeix
	FROM CANVI 
	WHERE divisa = paramDivisa AND dia = paramDia;
	
	IF (existeix = 0) THEN
		INSERT INTO CANVI VALUES (paramDivisa, paramDia, paramCanvi);
	ELSE
		UPDATE CANVI set canvi = paramCanvi
		WHERE divisa = paramDivisa AND dia = paramDia;
	END IF;
		
RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP || ' - Alta CANVI realitzada correctament.' );
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END ins_Canvi ;
/