/* ****************************************************
PROCEDIMENTS MODUL ESTADSTIC - REF.Enunciat_TFC_BDR_201302 AP.8

@Nom:				act_EST_85
@Funcionalitat:		Calcula i emmagatzema el sou mig dels jugadors en la taula EST_85, per a cada gnere, modalitat, pas i temporada.	
@params IN:		paramPais VARCHAR2(20 CHAR),
				paramTemporada VARCHAR2(9 CHAR),
				paramGenere VARCHAR2(1 CHAR), 
				paramModalitat VARCHAR2(15 CHAR),
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */  
create or replace PROCEDURE act_EST_85
(
  paramPais		IN VARCHAR2,  
  paramTemporada		IN VARCHAR2,
  paramGenere		IN VARCHAR2, 
  paramModalitat		IN VARCHAR2, 
    
  RSP 			OUT NOCOPY VARCHAR2
)
AS
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);  
  MSG_ERR	VARCHAR2(56);
 
  existeix INTEGER;
  varSMig NUMBER;
 
BEGIN
RSP := 'KO';
procediment := 'act_EST_85'; 
paramEntrada := 'Pais: ' || paramPais || 
          ' - Temporada: ' || paramTemporada || 
          ' - Genere: ' || paramGenere || 
          ' - Modalitat: ' || paramModalitat ;	

-- Comprova si hi ha cap registre segon els parmetres d'entrada:
SELECT count(*) INTO existeix
FROM EST_85
WHERE pais = paramPais
	AND temporada = paramTemporada
	AND genere = paramGenere
	AND modalitat = paramModalitat ;

-- el SOU MIG es calcula en base als sous que consten en els contractes.
SELECT AVG(salariBrut) INTO varSMig
	FROM CONTRACTE c, JUGADOR j
	WHERE c.jugador = j.id_jugador
		AND j.nacionalitat = paramPais
		AND j.genere = paramGenere
		AND j.modalitat = paramModalitat
		AND (EXTRACT(year from c.data_inici) <= substr(paramTemporada,1,4)
			AND EXTRACT(year from c.data_fi) >= substr(paramTemporada,1,4))
		;
-- si el registre existeix, s'actualitza el souMig:
IF (existeix = 1) THEN
	UPDATE EST_85 SET souMig = varSMig
	WHERE pais = paramPais
		AND temporada = paramTemporada
		AND genere = paramGenere
		AND modalitat = paramModalitat;
-- si no hi ha cap registre previ, es crea un nou registre:
ELSIF (existeix=0) THEN
	INSERT INTO EST_85 VALUES (paramPais, paramTemporada, paramGenere, paramModalitat, varSMig);
  
END IF;	
      
RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);   
       
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END act_EST_85 ;
/
