/* ****************************************************
PROCEDIMENTS MODUL ESTADSTIC - REF.Enunciat_TFC_BDR_201302 AP.8

@Nom:				act_EST_87
@Funcionalitat:		Per a cada gnere i modalitat, el millor jugador del mn en el darrer any (mitjana de valoracions ponderades ms alta).
@params IN:		paramGenere VARCHAR2(1 CHAR),
				paramModalitat VARCHAR2(15 CHAR),
@params OUT:	paramEntrada VARCHAR2(512),
				procediment VARCHAR2(24);
				text VARCHAR2(512);
				RSP
@error			MSG_ERR amb imformaci de l'error
**************************************************** */  
create or replace PROCEDURE act_EST_87
(
  paramGenere		IN EST_87.genere%TYPE,
  paramModalitat	IN EST_87.modalitat%TYPE,  
    
  RSP 			OUT NOCOPY VARCHAR2
)
AS
  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);  
  MSG_ERR	VARCHAR2(56);
 
  existeix INTEGER;
  varNom VARCHAR2(20);
  varCognom VARCHAR2(20);
  varJugador VARCHAR2(40);
  varVP	NUMBER;
 
BEGIN
RSP := 'KO';
procediment := 'act_EST_87'; 
paramEntrada := 'Genere: ' || paramGenere ||
          ' - Modalitat: ' || paramModalitat ;	

-- esbrina quin jugador t mitjana de les valoracions ponderades ms alta:
SELECT nom, cognom, punts INTO varNom, varCognom, varVP
FROM
(
  SELECT j.nom AS nom, j.cognom1 AS cognom, AVG(p.VP) AS punts
  FROM JUGADOR j, EQUIP e, PARTICIPA p, PARTIT t, NACIONAL n
  WHERE j.id_jugador = p.jugador AND p.partit = t.id_partit AND t.competicio = n.id_competicio
  HAVING AVG(p.VP) = (SELECT MAX(PROMIG)
    FROM (SELECT AVG(p.VP) AS PROMIG
            FROM JUGADOR j, EQUIP e, PARTICIPA p, PARTIT t, NACIONAL n
            WHERE j.id_jugador = p.jugador AND p.partit = t.id_partit AND t.competicio = n.id_competicio
            AND j.genere = paramGenere
            AND j.modalitat = paramModalitat
				    AND n.temporada = (SELECT MAX(id_temporada) FROM TEMPORADA)
            GROUP BY j.id_jugador)
          )
  GROUP BY j.nom, j.cognom1
) WHERE ROWNUM = 1;           

varJugador := varNom || ' ' || varCognom;
  
-- Comprova si hi ha cap registre segon els parmetres d'entrada:
SELECT count(*) INTO existeix
FROM EST_87
WHERE genere = paramGenere
	AND modalitat = paramModalitat;

  IF (existeix = 1) THEN
    UPDATE EST_87 SET millorJugador = varJugador, valorMig = varVP
    WHERE genere = paramGenere
      AND modalitat = paramModalitat;

  -- si no hi ha cap registre previ, es crea el registre amb el sou del primer contracte afectat:
  ELSIF (existeix=0) THEN
    INSERT INTO EST_87 VALUES(paramGenere, paramModalitat, varJugador, varVP);
  END IF;
    
RSP:='OK';
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  
       
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END act_EST_87;
/
