/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:	slt_7A
@Funcionalitat:	Retorna un llistat de tots els jugadors duna competici donada amb totes les seves dades, incloent la data de finalitzaci de contracte actual.
@params IN:	paramCompeticio NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
	RSP
@error	MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE slt_7A 
(
  paramCompeticio	IN NUMBER,
  
  RSP 			OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(4096);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(128);
  MSG_NN 	VARCHAR2(64);
  MSG_EX 	VARCHAR2(64);
  
  existeix	NUMBER;
  
  varID NUMBER; 
  varNom VARCHAR2(20);
  varCognom1 VARCHAR2(20);
  varGenere VARCHAR2(1);
  varModalitat VARCHAR2(15);
  varNacionalitat VARCHAR2(20);
  varDataNaixement DATE;
  varAlada NUMBER;
  varPes NUMBER;
  varPosicio NUMBER;
  varUrl VARCHAR2(40);
  varUrlVideo VARCHAR2(40);
  varActivitat VARCHAR2(7);
  varEstat VARCHAR2(5);
  varEquip VARCHAR2(25);
  varSou NUMBER;
  varFiContracte	 DATE;
  
  CURSOR cursor_A IS
  SELECT DISTINCT j.id_jugador, j.nom, j.cognom1, j.genere, j.modalitat, j.nacionalitat, j.dataNaixement, j.alada, j.pes, j.posicio, j.url, j.urlVideo, j.activitat, j.estat, e.nom, c.salariBrut, c.data_fi 
  FROM JUGADOR j INNER JOIN CONTRACTE c ON j.id_jugador = c.jugador
    INNER JOIN PARTICIPA p ON c.jugador = p.jugador 
      INNER JOIN PARTIT t ON p.partit = t.id_partit 
        INNER JOIN EQUIP e ON ((t.eqLocal = e.id_equip AND t.eqLocal = c.equipC)
                          OR (t.eqVisitant = e.id_equip AND t.eqVisitant = c.equipC))
	AND t.competicio = paramCompeticio;
     
BEGIN
RSP := 'KO';
procediment := 'sel_7A'; 
paramEntrada := 'Competici: ' || paramCompeticio;	

-- comprovar dades d'entrada:   
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NOM.';
		RAISE ERR_NN;
	END IF;
	
-- comprovar si existeix la competicio:
	SELECT id_competicio INTO existeix
	FROM COMPETICIO
	WHERE id_competicio = paramCompeticio;
	
	IF (existeix = 0) THEN
		MSG_EX := 'La competicio ' || paramCompeticio || ' no existeix a taula POSICIO de la BD.';
		RAISE ERR_EX;
	END IF;

-- crida i procs del cursor:
OPEN cursor_A;

loop 
	FETCH cursor_A INTO varID, varNom, varCognom1, varGenere, varModalitat, varNacionalitat, varDataNaixement, varAlada, varPes, varPosicio, varUrl, varUrlVideo, varActivitat, varEstat, varEquip, varSou, varFiContracte;
	EXIT WHEN cursor_A%notfound;
	
	--tractament de la var1 segons la sortida que volem:
	DBMS_OUTPUT.PUT_LINE(varID || ', ' || varNom || ', ' || varCognom1 || ', ' || varGenere || ', ' || varModalitat || ', ' || varNacionalitat || ', ' || varDataNaixement || ', ' || varAlada || ', ' || varPes || ', ' || varPosicio || ', ' || varUrl || ', ' || varUrlVideo || ', ' || varActivitat || ', ' || varEstat || ', ' || varEquip || ', ' || varSou || ', ' || varFiContracte);
END LOOP;

-- tanca el cursor
CLOSE cursor_A;

RSP:='OK' || ' - ' || text;
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7A;
/
