create or replace 
TYPE TY_slt7A_cap AS OBJECT 
(
  Identificador NUMBER,
  Nom VARCHAR2(20),
  Cognom VARCHAR2(20),
  Genere VARCHAR2(1),
  Modalitat VARCHAR2(15),
  Nacionalitat VARCHAR2(20),
  DataNaixement DATE,
  Alada NUMBER,
  Pes NUMBER,
  Posicio NUMBER,
  Url VARCHAR2(40),
  UrlVideo VARCHAR2(40),
  Activitat VARCHAR2(7),
  Estat VARCHAR2(5),
  Equip VARCHAR2(25),
  Sou NUMBER,
  FiContracte DATE
);
/
create or replace 
TYPE TY_slt7A_tab AS TABLE OF TY_slt7A_cap;
/
/* ****************************************************
CONSULTES - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:	slt_7AF
@Funcionalitat:	Retorna el llistat de tots els jugadors d'una competici donada  amb totes les seves dades, incloent la data de finalitzaci del contractes actual.
@params IN:	paramCompeticio NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
	RSP
@error	MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace FUNCTION slt_7AF
(
  paramCompeticio	IN NUMBER
)
    RETURN TY_slt7A_TAB
AS

  paramEntrada	VARCHAR2(4096);
  funcio   VARCHAR2(24);
  text		VARCHAR2(4096);
  RSP	           VARCHAR2(8);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(128);
  MSG_NN 	VARCHAR2(64);
  MSG_EX 	VARCHAR2(64);
  
  sortida TY_slt7A_TAB := TY_slt7A_TAB();
  
  existeix	NUMBER;
  i	INTEGER := 1; 
  
  Identificador NUMBER;
  Nom VARCHAR2(20);
  Cognom VARCHAR2(20);
  Genere VARCHAR2(1);
  Modalitat VARCHAR2(15);
  Nacionalitat VARCHAR2(20);
  DataNaixement DATE;
  Alada NUMBER;
  Pes NUMBER;
  Posicio NUMBER;
  Url VARCHAR2(40);
  UrlVideo VARCHAR2(40);
  Activitat VARCHAR2(7);
  Estat VARCHAR2(5);
  Equip VARCHAR2(25);
  Sou NUMBER;
  FiContracte DATE;
    
  CURSOR cursor_A IS
  SELECT DISTINCT j.id_jugador, j.nom, j.cognom1, j.genere, j.modalitat, j.nacionalitat, j.dataNaixement, j.alada, j.pes, j.posicio, j.url, j.urlVideo, j.activitat, j.estat, e.nom, c.salariBrut, c.data_fi 
  FROM JUGADOR j INNER JOIN CONTRACTE c ON j.id_jugador = c.jugador
    INNER JOIN PARTICIPA p ON c.jugador = p.jugador 
      INNER JOIN PARTIT t ON p.partit = t.id_partit 
        INNER JOIN EQUIP e ON ((t.eqLocal = e.id_equip AND t.eqLocal = c.equipC)
                          OR (t.eqVisitant = e.id_equip AND t.eqVisitant = c.equipC))
	AND t.competicio = paramCompeticio;
     
BEGIN
RSP := 'KO';
funcio := 'sel_7A'; 
paramEntrada := 'Competici: ' || paramCompeticio;	

-- comprovar dades d'entrada:   
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NOM.';
		RAISE ERR_NN;
	END IF;
	
-- comprovar si existeix la competicio:
	SELECT id_competicio INTO existeix
	FROM COMPETICIO
	WHERE id_competicio = paramCompeticio;
	
	IF (existeix = 0) THEN
		MSG_EX := 'La competicio ' || paramCompeticio || ' no existeix a taula POSICIO de la BD.';
		RAISE ERR_EX;
	END IF;

-- crida i procs del cursor:
OPEN cursor_A;
                                                                                                                                                                                     
loop 
	FETCH cursor_A INTO Identificador, Nom, Cognom, Genere, Modalitat, Nacionalitat, DataNaixement, Alada, Pes, Posicio, Url, UrlVideo, Activitat, Estat, Equip, Sou, FiContracte;
	EXIT WHEN cursor_A%notfound;
    sortida.extend;
    sortida(i) := TY_slt7A_CAP(Identificador, Nom, Cognom, Genere, Modalitat, Nacionalitat, DataNaixement, Alada, Pes, Posicio, Url, UrlVideo, Activitat, Estat, Equip, Sou, FiContracte);
    i := i + 1;
END LOOP;

-- tanca el cursor
CLOSE cursor_A;

RETURN sortida;

RSP:='OK';
INSERT INTO LOG_CONSULTES_SLT7 VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS'), funcio, RSP, paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG_CONSULTES_SLT7 VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS'), funcio, RSP, paramEntrada || MSG_ERR);

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
      INSERT INTO LOG_CONSULTES_SLT7 VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS'), funcio, RSP, paramEntrada || MSG_ERR);
	 
  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
      INSERT INTO LOG_CONSULTES_SLT7 VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS'), funcio, RSP, paramEntrada || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7AF;
/
