create or replace 
TYPE TY_slt7B_cap AS OBJECT 
(
  EQUIP		VARCHAR2(25),
  PUNTS		NUMBER
);
/
create or replace 
TYPE TY_slt7B_tab AS TABLE OF TY_slt7B_cap;
/
/* ****************************************************
CONSULTES - REF.Enunciat_TFC_BDR_201302 AP.6

@Nom:			slt_7BF
@Funcionalitat:	Retorna un llistat de tots els equips d'una competicio ordenats pel nombre de punts totals a favor en la temporada actual.
@params IN:	paramCompeticio NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
			procediment VARCHAR2(24);
			text VARCHAR2(512);
			RSP
@error		MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace 
FUNCTION slt_7BF 
(
  paramCompeticio	IN NUMBER
)
RETURN TY_slt7B_TAB
AS

  paramEntrada	VARCHAR2(512);
  funcio   VARCHAR2(24);
  text		VARCHAR2(512);
  RSP	           VARCHAR2(8);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(56);
  MSG_NN 	VARCHAR2(25);
  MSG_EX 	VARCHAR2(25);
  
  sortida   TY_slt7B_TAB := TY_slt7B_TAB();

  existeix	NUMBER;
  i	INTEGER := 1;
  
  varEquip VARCHAR2(25);
  varPunts NUMBER;

  CURSOR cursor_B IS
  SELECT e.nom AS EQUIP, cl.punts AS PUNTS  
  FROM CLASSIFICACIO cl, COMPETICIO c, EQUIP e
  WHERE cl.competicio = c.id_competicio
	AND cl.equip = e.id_equip
	AND cl.competicio= paramCompeticio
	-- i la temporada
  ORDER BY cl.punts DESC;
     
BEGIN
--RSP := 'KO';
funcio := 'sel_7B'; 
paramEntrada := 'Competici: ' || paramCompeticio;	

-- comprovar dades d'entrada:   
	IF (paramCompeticio IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp NOM.';
		RAISE ERR_NN;
	END IF;
	
-- comprovar si existeix la competicio:
	SELECT id_competicio INTO existeix
	FROM COMPETICIO
	WHERE id_competicio = paramCompeticio;
	
	IF (existeix = 0) THEN
		MSG_EX := 'La competicio ' || paramCompeticio || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

-- crida i procs del cursor:
OPEN cursor_B;

loop 
	FETCH cursor_B INTO varEquip, varPunts;
	EXIT WHEN cursor_B%notfound;
	sortida.extend();
	sortida(i) := TY_slt7B_CAP(varEquip, varpunts);
	i := i + 1;
END LOOP;

-- tanca el cursor
CLOSE cursor_B;

-- presenta la sortida en format taula
RETURN sortida;

RSP:='OK';
INSERT INTO LOG_CONSULTES_SLT7 VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS'), funcio, RSP, paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (Funcio  || ' - ' || paramEntrada || ' - ' || RSP);  
    	 INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP); 
 	 DBMS_OUTPUT.PUT_LINE(text);
	 
  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (Funcio  || ' - ' || paramEntrada || ' - ' || RSP);  
    	 INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP); 
 	 DBMS_OUTPUT.PUT_LINE(text);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7BF;
/
