/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:	slt_7C
@Funcionalitat:	Donats un mbit, un gnere i una modalitat de competici, retorna el llistat dels 5 millors jugadors per posici en funci de la seva valoraci.
@params IN:	paramAmbit VARCHAR2(13),
	paramGenere VARCHAR2(1)
	paramModalitat VARCHAR2(15),
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
	RSP
@error	MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE slt_7C 
(
  paramAmbit	IN COMPETICIO.ambit%TYPE,
  paramGenere	IN COMPETICIO.genere%TYPE,
  paramModalitat	IN COMPETICIO.modalitat%TYPE,
  RSP	OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment   VARCHAR2(24);
  text		VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(56);
  MSG_NN 	VARCHAR2(25);
  MSG_EX 	VARCHAR2(25);
  
  existeix	NUMBER;
  
  varNom VARCHAR2(20);
  varCognom VARCHAR2(20);
  varPosicio VARCHAR2(20);
  varValoracio NUMBER;

  varPos1 NUMBER;
  varPos2 NUMBER;
   
  CURSOR cursor_C IS
  SELECT NOM, COGNOM, POSICIO, PUNTS 
FROM (
SELECT j.nom as NOM, j.cognom1 AS COGNOM, J.POSICIO AS POSICIO, AVG(P.VP) AS PUNTS
FROM COMPETICIO c, PARTIT t, EQUIP e, JUGADOR j, PARTICIPA p
	WHERE c.id_competicio = t.competicio
		AND (t.eqLocal = e.id_equip OR t.eqVisitant = e.id_equip)
		AND t.id_partit = p.partit
		AND p.jugador = j.id_jugador
		AND c.ambit = 'NACIONAL'
		AND c.genere = 'M'
		AND c.modalitat = 'NORMAL'
    AND j.posicio = varPos2
	GROUP BY j.NOM, J.COGNOM1, j.posicio 
  ORDER BY 4 DESC
) WHERE ROWNUM BETWEEN 1 AND 5
;
      
BEGIN
RSP:='OK';
procediment := 'slt_7C'; 
paramEntrada := 'mbit: ' || paramAmbit ||
		' - Genere: ' || paramGenere ||
		' - Modalitat: ' || paramModalitat;	

-- comprovar dades d'entrada:   
	IF (paramAmbit IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp AMBIT = (NACIONAL,CONTINENTAL).';
		RAISE ERR_NN;
	END IF;
	IF (paramGenere IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp GENERE = (M,F).';
		RAISE ERR_NN;
	END IF;
	IF (paramModalitat IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp MODALITAT = (NORMAL,CADIRA DE RODES).';
		RAISE ERR_NN;
	END IF;
  
  SELECT count(*) INTO varPos1
  FROM POSICIO;  
  
FOR comptador IN 1..varPos1 LOOP
  varPos2 := comptador;
  -- Instruccions a realitzar paramDurada vegades:
  -- crida i procs del cursor:
  OPEN cursor_C;
  LOOP
    FETCH cursor_C INTO varNom, varCognom, varPosicio, varValoracio;
    EXIT WHEN cursor_C%notfound;
    
    --tractament de la sortida:
	DBMS_OUTPUT.PUT_LINE(varNom || ',' || varCognom || ',' || varPosicio || ',' ||varValoracio);
  END LOOP;
  -- tanca el cursor
  CLOSE cursor_C;
END LOOP;

RSP:='OK' || ' - ' || text;
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7C;
/
