create or replace 
TYPE TY_slt7C_cap AS OBJECT 
(
  NOM		VARCHAR2(20),	
  COGNOM		VARCHAR2(20),	
  POSICIO	NUMBER,
  VALORACIO	NUMBER
);
/
create or replace 
TYPE TY_slt7C_tab AS TABLE OF TY_slt7C_cap;
/
/* ****************************************************
CONSULTES - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:	slt_7C
@Funcionalitat:	Donats un mbit, un gnere i una modalitat de competici, retorna el llistat dels 5 millors jugadors per posici en funci de la seva valoraci.
@params IN:	paramAmbit VARCHAR2(13),
	paramGenere VARCHAR2(1)
	paramModalitat VARCHAR2(15),
@params OUT:	paramEntrada VARCHAR2(512),
	funcio VARCHAR2(24);
	text VARCHAR2(512);
	RSP
@error	MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace FUNCTION slt_7CF
(
  paramAmbit	IN COMPETICIO.ambit%TYPE,
  paramGenere	IN COMPETICIO.genere%TYPE,
  paramModalitat	IN COMPETICIO.modalitat%TYPE
)
RETURN TY_slt7C_TAB
AS

  paramEntrada	VARCHAR2(4096);
  funcio	VARCHAR2(24);
  text	VARCHAR2(4096);
  RSP	VARCHAR2(8);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(56);
  MSG_NN	VARCHAR2(25);
  MSG_EX	VARCHAR2(25);

  sortida	TY_slt7C_TAB := TY_slt7C_TAB();
  
  existeix	NUMBER;
  i	INTEGER := 1;
  
  varNom VARCHAR2(20);
  varCognom VARCHAR2(20);
  varPosicio VARCHAR2(20);
  varValoracio NUMBER;
  
  varPos NUMBER;

  CURSOR cursor_C IS
  SELECT j.nom, j.cognom1, j.posicio, AVG(vp) AS promig
  FROM COMPETICIO c, PARTIT t, EQUIP e, JUGADOR j, PARTICIPA p
  WHERE c.id_competicio = t.competicio
	AND (t.eqLocal = e.id_equip OR t.eqVisitant = e.id_equip)
	AND t.id_partit = p.partit
	AND p.jugador = j.id_jugador
	AND c.ambit = paramAmbit
	AND c.genere = paramGenere
	AND c.modalitat = paramModalitat
  AND j.posicio = varPos
  HAVING AVG(vp) = (SELECT MAX(promig2)
                FROM (SELECT AVG(vp)AS promig2
				FROM COMPETICIO c, PARTIT t, EQUIP e, JUGADOR j, PARTICIPA p
				WHERE c.id_competicio = t.competicio
				AND (t.eqLocal = e.id_equip OR t.eqVisitant = e.id_equip)
				AND t.id_partit = p.partit
				AND p.jugador = j.id_jugador
				AND c.ambit = paramAmbit
				AND c.genere = paramGenere
				AND c.modalitat = paramModalitat
        AND j.posicio = varPos
				GROUP BY j.id_jugador, j.posicio ))
  GROUP BY j.nom, j.cognom1, j.posicio
  ;
      
BEGIN
RSP := 'KO';
funcio := 'slt_7C'; 
paramEntrada := 'mbit: ' || paramAmbit ||
		' - Genere: ' || paramGenere ||
		' - Modalitat: ' || paramModalitat;	

-- comprovar dades d'entrada:   
	IF (paramAmbit IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp AMBIT = (NACIONAL,CONTINENTAL).';
		RAISE ERR_NN;
	END IF;
	IF (paramGenere IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp GENERE = (M,F).';
		RAISE ERR_NN;
	END IF;
	IF (paramModalitat IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp MODALITAT = (NORMAL,CADIRA DE RODES).';
		RAISE ERR_NN;
	END IF;

  -- quin s el nmero de posicions?
  SELECT count(*) INTO varPos
  FROM POSICIO;  
  
FOR comptador IN 1..varPos LOOP
  -- Instruccions a realitzar paramDurada vegades:
  -- crida i procs del cursor:
  OPEN cursor_C;    
  LOOP
    FETCH cursor_C INTO varNom, varCognom, varPosicio, varValoracio;
    EXIT WHEN cursor_C%notfound;
    sortida.extend;
    sortida(i) := TY_slt7C_CAP(varNom, varCognom, varPosicio, varValoracio);
    i := i + 1;
  END LOOP;
  -- tanca el cursor
  CLOSE cursor_C;
varPos := varPos - 1;
END LOOP;

RETURN sortida;

RSP:='OK';
INSERT INTO LOG_CONSULTES_SLT7 VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS'), funcio, RSP, paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (Funcio  || ' - ' || paramEntrada || ' - ' || RSP);  
    	 INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP); 
 	 DBMS_OUTPUT.PUT_LINE(text);
	 
  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (Funcio  || ' - ' || paramEntrada || ' - ' || RSP);  
    	 INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP); 
 	 DBMS_OUTPUT.PUT_LINE(text);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7CF;
/
