/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:	slt_7D
@Funcionalitat:	Donat un any i un representant de jugadors, retorna el nmero de contractes de jugadors signats i el valor econmic total de cadascun d'ells.
@params IN:	paramAny NUMBER,
	paramRep NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
	RSP
@error	MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace PROCEDURE slt_7D 
(
  paramAny	IN NUMBER,
  paramRep	IN NUMBER,
  RSP	OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment	VARCHAR2(24);
  text	VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(56);
  MSG_NN	VARCHAR2(25);
  MSG_EX	VARCHAR2(25);
  
  existeix	NUMBER;
   
  varNom	VARCHAR2(20);
  varCognom1	VARCHAR2(20);
  varValor	NUMBER;
  varContractes	NUMBER;
  
  CURSOR cursor_D IS       
SELECT j.nom, j.cognom1, c.valor INTO varNom, varCognom1, varValor
FROM REP_JUGADOR rj, JUGADOR j, CONTRACTE c
WHERE rj.jugador = j.id_jugador AND rj.representant = paramRep
AND c.jugador = j.id_jugador
AND c.data_inici between rj.data_inici AND rj.data_fi;

BEGIN
RSP := 'KO';
procediment := 'slt_7D'; 
paramEntrada := 'Any: ' || paramAny ||
		' - Representant: ' || paramRep;	

-- comprovar dades d'entrada:   
	IF (paramRep IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp REPRESENTANT.';
		RAISE ERR_NN;
	END IF;
	
-- comprovar si existeix el representant:
	SELECT id_representant INTO existeix
	FROM REPRESENTANT
	WHERE id_representant = paramRep;
	
	IF (existeix = 0) THEN
		MSG_EX := 'El representant ' || paramRep || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

-- calcula el nmero de contractes de jugadors signats:
SELECT COUNT(*) INTO varContractes
FROM REP_JUGADOR rj, JUGADOR j, CONTRACTE c
WHERE rj.jugador = j.id_jugador AND rj.representant = paramRep
AND c.jugador = j.id_jugador
AND c.data_inici between rj.data_inici AND rj.data_fi;

IF (varContractes > 0) THEN
  -- cerca del valor econmic total de cadascun dels contractes:
  -- crida i procs del cursor:
  OPEN cursor_D;
  LOOP 
    FETCH cursor_D INTO varNom, varCognom1, varValor;
    EXIT WHEN cursor_D%notfound;	
    --tractament de la sortida:
    DBMS_OUTPUT.PUT_LINE(varNom || ',' || varCognom1 || ',' || varValor || '- Total contractes: ' || varContractes);
  END LOOP;
  -- tanca el cursor
  CLOSE cursor_D;
ELSIF (varContractes = 0) THEN
  text := 'No hi ha registres per a aquesta selecci.';
END IF;

RSP:='OK' || '-' || text;
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7D;
/