create or replace 
TYPE TY_slt7D_cap AS OBJECT 
(
  NOM		VARCHAR2(20),
  COGNOM		VARCHAR2(20),
  VALOR	NUMBER
);
/
create or replace 
TYPE TY_slt7D_tab AS TABLE OF TY_slt7D_cap;
/
/* ****************************************************
CONSULTES - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:	slt_7D
@Funcionalitat:	Donat un any i un representant de jugadors, retorna el nmero de contractes de jugadors signats i el valor econmic total de cadascun d'ells.
@params IN:	paramAny NUMBER,
	paramRep NUMBER,
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
	RSP
@error	MSG_ERR amb imformaci de l'error
**************************************************** */ 
create or replace FUNCTION slt_7DF
(
  paramAny	IN NUMBER,
  paramRep	IN NUMBER
)
  RETURN 	TY_slt7D_TAB
AS

  paramEntrada	VARCHAR2(4096);
  funcio	VARCHAR2(24);
  text	VARCHAR2(4096);
  RSP	VARCHAR2(8);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(56);
  MSG_NN	VARCHAR2(25);
  MSG_EX	VARCHAR2(25);

  sortida	TY_slt7D_TAB := TY_slt7D_TAB();
  
  existeix	NUMBER;
  i	INTEGER := 1; 
   
  varNom	VARCHAR2(20);
  varCognom	VARCHAR2(20);
  varValor	NUMBER;
  varContractes	NUMBER;
  
  CURSOR cursor_D IS       
SELECT j.nom, j.cognom1, c.valor INTO varNom, varCognom, varValor
FROM REP_JUGADOR rj INNER JOIN CONTRACTE c ON c.JUGADOR = rj.JUGADOR
  INNER JOIN JUGADOR j ON j.id_jugador = c.jugador
WHERE RJ.DATA_INICI < C.DATA_INICI AND RJ.DATA_FI IS NULL
AND EXTRACT (year FROM c.data_inici) = paramAny
AND rj.representant = paramRep;

BEGIN
RSP := 'KO';
funcio := 'slt_7D'; 
paramEntrada := 'Any: ' || paramAny ||
		' - Representant: ' || paramRep;	

-- comprovar dades d'entrada:   
	IF (paramRep IS NULL) THEN
		MSG_NN := 'Cal emplenar el camp REPRESENTANT.';
		RAISE ERR_NN;
	END IF;
	
-- comprovar si existeix el representant:
	SELECT id_representant INTO existeix
	FROM REPRESENTANT
	WHERE id_representant = paramRep;
	
	IF (existeix = 0) THEN
		MSG_EX := 'El representant ' || paramRep || ' no existeix a la BD.';
		RAISE ERR_EX;
	END IF;

-- calcula el nmero de contractes de jugadors signats:
SELECT COUNT(*) INTO varContractes
FROM REP_JUGADOR rj, JUGADOR j, CONTRACTE c
WHERE rj.jugador = j.id_jugador AND rj.representant = paramRep
AND c.jugador = j.id_jugador
AND c.data_inici between rj.data_inici AND rj.data_fi;

OPEN cursor_D;

  LOOP 
  	FETCH cursor_D INTO varNom, varCognom, varValor;
    EXIT WHEN cursor_D%notfound;	
    sortida.extend;
    sortida(i) := TY_slt7D_CAP(varNom, varCognom, varValor);
    i := i+1;
  END LOOP;

  -- tanca el cursor
CLOSE cursor_D;

RETURN sortida;

RSP:='OK';
INSERT INTO LOG_CONSULTES_SLT7 VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS'), funcio, RSP, paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (Funcio  || ' - ' || paramEntrada || ' - ' || RSP);  
    	 INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP); 
 	 DBMS_OUTPUT.PUT_LINE(text);
	 
  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (Funcio  || ' - ' || paramEntrada || ' - ' || RSP);  
    	 INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP); 
 	 DBMS_OUTPUT.PUT_LINE(text);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7DF;
/
