/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:	slt_7E
@Funcionalitat:	Donat un any concret, mostra el llistat dels 10 equips que ms diners s'han gastat en adquisici de jugadors, ordenat de ms a menys.
@params IN:	paramAny	NUMBER,				
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
	RSP
@error	MSG_ERR amb imformaci de l'error
**************************************************** */  
create or replace PROCEDURE slt_7E 
(
  paramAny	IN NUMBER,   
  RSP	OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment	VARCHAR2(24);
  text	VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(56);
  MSG_NN	VARCHAR2(25);
  MSG_EX	VARCHAR2(25);
  
  existeix	NUMBER;
  
  varNom	VARCHAR2(20);
  varDiners	NUMBER;

  CURSOR cursor_E IS
  SELECT nom, despesa
  FROM (SELECT e.nom AS nom, SUM(c.clausula + c.salariBrut * durada) AS despesa, row_number() over (order BY SUM(c.clausula + c.salariBrut * durada) DESC) r
      	FROM CONTRACTE c, EQUIP e   
		WHERE c.equipC = e.id_equip
		AND EXTRACT (year FROM c.data_inici) = paramAny
  		GROUP BY e.nom
  		)
  WHERE r BETWEEN 1 AND 10;
 
BEGIN
RSP := 'KO';
procediment := 'slt_7E'; 
paramEntrada := 'Any: ' || paramAny;	

-- crida i procs del cursor:
OPEN cursor_E;

loop 
	FETCH cursor_E INTO varNom, varDiners;
	EXIT WHEN cursor_E%notfound;
	
	--tractament de la sortida:
	DBMS_OUTPUT.PUT_LINE(varNom || ' ' || varDiners);
END LOOP;

-- tanca el cursor
CLOSE cursor_E;

RSP:='OK' || '-' || text;
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7E;
/