create or replace 
TYPE TY_slt7E_cap AS OBJECT 
(
  EQUIP	VARCHAR2(25),
  DESPESA	NUMBER
);
/
create or replace 
TYPE TY_slt7E_tab AS TABLE OF TY_slt7E_cap;
/
/* ****************************************************
CONSULTES - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:	slt_7E
@Funcionalitat:	Donat un any concret, mostra el llistat dels 10 equips que ms diners s'han gastat en adquisici de jugadors, ordenat de ms a menys.
@params IN:	paramAny	NUMBER,				
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
	RSP
@error	MSG_ERR amb imformaci de l'error
**************************************************** */  
create or replace FUNCTION slt_7EF
(
  paramAny	IN NUMBER   
)
  RETURN 	TY_slt7E_TAB
AS

  paramEntrada	VARCHAR2(4096);
  funcio	VARCHAR2(24);
  text	VARCHAR2(4096);
  RSP	VARCHAR2(8);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(56);
  MSG_NN	VARCHAR2(25);
  MSG_EX	VARCHAR2(25);
  
  sortida	TY_slt7E_TAB := TY_slt7E_TAB();
  
  existeix	NUMBER;
  i	INTEGER := 1; 
  
  varEquip	VARCHAR2(25);
  varDiners	NUMBER;

  CURSOR cursor_E IS
  SELECT nom, despesa
  FROM (SELECT e.nom AS nom, SUM(c.clausula + c.salariBrut * durada) AS despesa, row_number() over (order BY SUM(c.clausula + c.salariBrut * durada) DESC) r
      	FROM CONTRACTE c, EQUIP e   
		WHERE c.equipC = e.id_equip
		AND EXTRACT (year FROM c.data_inici) = paramAny
  		GROUP BY e.nom
  		)
  WHERE r BETWEEN 1 AND 10;
 
BEGIN
RSP := 'KO';
funcio := 'slt_7E'; 
paramEntrada := 'Any: ' || paramAny;	

-- crida i procs del cursor:
OPEN cursor_E;

  LOOP 
	FETCH cursor_E INTO varEquip, varDiners;
    EXIT WHEN cursor_E%notfound;	
    sortida.extend;
    sortida(i) := TY_slt7E_CAP(varEquip, varDiners);
    i := i+1;
  END LOOP;

-- tanca el cursor
CLOSE cursor_E;

RETURN sortida;

RSP:='OK';
INSERT INTO LOG_CONSULTES_SLT7 VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS'), funcio, RSP, paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);  

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (Funcio  || ' - ' || paramEntrada || ' - ' || RSP);  
    	 INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP); 
 	 DBMS_OUTPUT.PUT_LINE(text);
	 
  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (Funcio  || ' - ' || paramEntrada || ' - ' || RSP);  
    	 INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || funcio || ' - ' || RSP); 
 	 DBMS_OUTPUT.PUT_LINE(text);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7EF;
/
