/* ****************************************************
PROCEDIMENTS ABM - REF.Enunciat_TFC_BDR_201302 AP.7

@Nom:	slt_7F
@Funcionalitat:	Donat un pas, un gnere i una modalitat, mostra el llistat dels jugadors que acaben contracte a final de la present temporada o que estan en actiu, per sense equip.
@params IN:	paramPais	VARCHAR2(20),
			paramGenere VARCHAR2(1),
			paramModalitat VARCHAR2(15),		
@params OUT:	paramEntrada VARCHAR2(512),
	procediment VARCHAR2(24);
	text VARCHAR2(512);
	RSP
@error	MSG_ERR amb imformaci de l'error
**************************************************** */  
create or replace PROCEDURE slt_7F 
(
  paramPais	IN JUGADOR.nacionalitat%TYPE,
  paramGenere	IN JUGADOR.genere%TYPE,
  paramModalitat	IN JUGADOR.modalitat%TYPE,
  RSP	OUT NOCOPY VARCHAR2
)
AS

  paramEntrada	VARCHAR2(512);
  procediment	VARCHAR2(24);
  text	VARCHAR2(512);
   
  ERR_NUM	NUMBER(6);
  ERR_NN	EXCEPTION;
  ERR_EX	EXCEPTION;

  MSG_ERR	VARCHAR2(56);
  MSG_NN	VARCHAR2(25);
  MSG_EX	VARCHAR2(25);
  
  existeix	NUMBER;
  
  varNom	VARCHAR2(20);
  varCognom	VARCHAR2(20);
  varData	DATE;

  CURSOR cursor_F IS
  SELECT j.nom, j.cognom1, c.data_fi
  FROM JUGADOR j, CONTRACTE c
  WHERE c.jugador = j.id_jugador
	AND j.nacionalitat = paramPais
	AND j.genere = paramGenere
	AND j.modalitat = paramModalitat
	AND j.activitat = 'ACTIU'
	AND EXTRACT (year from c.data_fi) <= EXTRACT(year from sysdate);
 
BEGIN
RSP := 'KO';
procediment := 'slt_7F'; 
paramEntrada := 'Pais: ' || paramPais ||
		' - Gnere: ' || paramGenere ||
		' - Modalitat: ' || paramModalitat;	

-- crida i procs del cursor:
OPEN cursor_F;

loop 
	FETCH cursor_F INTO varNom, varCognom, varData;
	EXIT WHEN cursor_F%notfound;
	
	--tractament de la sortida:
	DBMS_OUTPUT.PUT_LINE(varNom || ' ' || varCognom || ', ' || varData);
END LOOP;

-- tanca el cursor
CLOSE cursor_F;

RSP:='OK' || '-' || text;
INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || RSP || ' - ' || Procediment  || ' - ' || paramEntrada);
DBMS_OUTPUT.PUT_LINE(RSP);
    
  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    ERR_NUM := -20008;   
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS')
		|| ' - ' || paramEntrada || ' - ' || procediment || ' - ' || RSP);
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);    

  WHEN ERR_NN THEN
    MSG_ERR := MSG_NN;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
    DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);

  WHEN ERR_EX THEN
    MSG_ERR := MSG_EX;
    text := (RSP || ' - ' || Procediment  || ' - ' || paramEntrada || ' - ' || MSG_ERR);
      INSERT INTO LOG VALUES(to_char(sysdate, 'DD-MM-YYYY HH24:MI:SS') || ' - ' || text );
 	DBMS_OUTPUT.PUT_LINE(RSP || ' - ' || Procediment || ' - ' || MSG_ERR);
    
  WHEN OTHERS THEN
      ERR_NUM := SQLCODE;  
      MSG_ERR := SQLERRM;  
      DBMS_OUTPUT.PUT_LINE('Error: ' || TO_CHAR(ERR_NUM) || ', ' || MSG_ERR);
    
END slt_7F;
/